@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2016 Parallel Realities
+Copyright (C) 2009-2024 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -245,7 +245,7 @@ Mix_Chunk *loadSound(char *name)
 		return NULL;
 	}
 
-	snprintf(path, sizeof(path), "%s", name);
+	SNPRINTF(path, sizeof(path), "%s", name);
 
 	/* Load the sound specified by the filename */
 
