@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2016 Parallel Realities
+Copyright (C) 2009-2024 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -59,7 +59,6 @@ static char *oldMusicTracks[] = {
 			"MAP24_MUSIC", "music/climax.it",
 			"MAP25_MUSIC", "music/crypt.xm",
 			"MAP26_MUSIC", "music/szc2_-_fight_for_your_lives.xm",
-			"MAP25_MUSIC", "music/crypt",
 			"TUTORIAL_MUSIC", "music/jk_village.xm",
 			"CREDITS_MUSIC", "music/credits.mod",
 			"GAMEOVER_MUSIC", "music/oxide_-_sadness.xm",
@@ -73,14 +72,14 @@ static char *newMusicTracks[] = {
 			"TITLE_MUSIC", "music/Menu_loop.ogg",
 			"MAP01_MUSIC", "music/Lazy Day v0_9.ogg",
 			"MAP02_MUSIC", "music/Ruinous Laments(5.6).ogg",
-			"MAP03_MUSIC", "music/Devilish design.ogg",
+			"MAP03_MUSIC", "music/Danza del bosque.ogg",
 			"MAP04_MUSIC", "music/Avgvst - Mushrooms_1.ogg",
 			"MAP05_MUSIC", "music/MysticalCaverns.ogg",
 			"MAP06_MUSIC", "music/Red Curtain.ogg",
 			"MAP07_MUSIC", "music/ratsrats_0.ogg",
 			"MAP08_MUSIC", "music/beauty_of_chaos.ogg",
 			"MAP09_MUSIC", "music/Battle in the winter.ogg",
-			"MAP10_MUSIC", "music/Devilish design.ogg",
+			"MAP10_MUSIC", "music/A tricky puzzle.ogg",
 			"MAP11_MUSIC", "music/Decision.ogg",
 			"MAP12_MUSIC", "music/Ruinous Laments(5.6).ogg",
 			"MAP13_MUSIC", "music/Heroic Minority.ogg",
@@ -180,6 +179,8 @@ void playMapMusic()
 	Mix_PlayMusic(music, -1);
 
 	Mix_VolumeMusic(game.musicDefaultVolume * VOLUME_STEPS);
+	
+	Mix_ResumeMusic();
 }
 
 void stopMusic()
