@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2016 Parallel Realities
+Copyright (C) 2009-2024 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -157,7 +157,7 @@ static void hunt()
 
 	/* Position under the player */
 
-	if (abs(self->x - self->targetX) <= self->speed * 3)
+	if (fabsf(self->x - self->targetX) <= self->speed * 3)
 	{
 		self->dirX = 0;
 
@@ -224,7 +224,7 @@ static void trapTarget(Entity *other)
 		return;
 	}
 
-	if (abs((self->y + self->h) - (other->y + other->h)) > 5)
+	if (fabsf((self->y + self->h) - (other->y + other->h)) > 5)
 	{
 		return;
 	}
