@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2016 Parallel Realities
+Copyright (C) 2009-2024 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -188,7 +188,7 @@ static void doIntro()
 	{
 		self->flags |= DO_NOT_PERSIST;
 
-		snprintf(name, sizeof(name), "boss/awesome_boss_%d", self->mental);
+		SNPRINTF(name, sizeof(name), "boss/awesome_boss_%d", self->mental);
 
 		e = addEnemy(name, self->x - 8 * self->mental, self->y - 64);
 
