@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2016 Parallel Realities
+Copyright (C) 2009-2024 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -35,6 +35,7 @@ Foundation, 51 Franklin Street, Suite 500, Boston, MA 02110-1335, USA.
 #include "../graphics/decoration.h"
 #include "../graphics/graphics.h"
 #include "../hud.h"
+#include "../init.h"
 #include "../inventory.h"
 #include "../item/key_items.h"
 #include "../map.h"
@@ -566,7 +567,7 @@ static void lightningCageMoveBackToPlayer()
 
 	/* Position above the player */
 
-	if (abs(self->x - self->targetX) <= player.speed / 2)
+	if (fabsf(self->x - self->targetX) <= player.speed / 2)
 	{
 		self->action = &lightningCage;
 
@@ -890,11 +891,22 @@ static void soulStealSpellAttack()
 
 int drawSoulStealSpell()
 {
-	int colour1, colour2, colour3;
+	Colour colour1, colour2, colour3;
 
-	colour1 = getColour(38, 152, 38);
-	colour2 = getColour(50, 200, 50);
-	colour3 = getColour(56, 225, 56);
+	colour1.r = 38;
+	colour1.g = 152;
+	colour1.b = 38;
+	colour1.a = 255;
+	
+	colour2.r = 50;
+	colour2.g = 200;
+	colour2.b = 50;
+	colour1.a = 255;
+	
+	colour3.r = 56;
+	colour3.g = 225;
+	colour3.b = 56;
+	colour1.a = 255;
 
 	drawDisintegrationLine(self->startX, self->startY, self->endX, self->endY, colour1, colour2, colour3);
 
@@ -1960,7 +1972,7 @@ static void raiseDead()
 
 	if (self->thinkTime <= 0)
 	{
-		snprintf(targetName, MAX_VALUE_LENGTH, "GRAVE_%c", self->description[self->mental]);
+		SNPRINTF(targetName, MAX_VALUE_LENGTH, "GRAVE_%c", self->description[self->mental]);
 
 		t = getTargetByName(targetName);
 
@@ -2041,7 +2053,7 @@ static void becomeTransparent()
 	{
 		printf("%s cannot become transparent!\n", self->name);
 
-		exit(1);
+		cleanup(1);
 	}
 
 	self->endX--;
