@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2016 Parallel Realities
+Copyright (C) 2009-2024 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -524,7 +524,7 @@ static void die()
 	Entity *e;
 	char name[MAX_VALUE_LENGTH];
 
-	snprintf(name, sizeof(name), "boss/gold_centurion_boss_piece");
+	STRNCPY(name, "boss/gold_centurion_boss_piece", sizeof(name));
 
 	playSoundToMap("sound/enemy/centurion/centurion_die", BOSS_CHANNEL, self->x, self->y, 0);
 
@@ -1140,7 +1140,7 @@ static void followPlayer()
 
 	/* Position above the player */
 
-	if (abs(self->x - self->targetX) <= abs(self->dirX))
+	if (fabsf(self->x - self->targetX) <= fabsf(self->dirX))
 	{
 		self->x = self->targetX;
 
