@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2016 Parallel Realities
+Copyright (C) 2009-2024 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -2318,7 +2318,7 @@ static void die()
 
 	self->weight = 1;
 
-	playSoundToMap("sound/boss/chaos/die", BOSS_CHANNEL, self->x, self->y, -1);
+	playSoundToMap("sound/boss/chaos/die", BOSS_CHANNEL, self->x, self->y, 0);
 
 	setEntityAnimation(self, "DIE_1");
 
