@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2016 Parallel Realities
+Copyright (C) 2009-2024 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -376,7 +376,7 @@ static void dropInit()
 	{
 		/* Move towards player */
 
-		if (abs(self->x - self->targetX) <= self->speed)
+		if (fabsf(self->x - self->targetX) <= self->speed)
 		{
 			self->dirX = 0;
 		}
