@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2016 Parallel Realities
+Copyright (C) 2009-2024 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -88,6 +88,7 @@ static void lanceAttack1Wait(void);
 static void lanceAttack2(void);
 static void lanceAttack3(void);
 static void lanceAttackTeleportFinish(void);
+static void lanceThrowTeleportFinish(void);
 static void lanceDie(void);
 static void weaponRemoveBlastInit(void);
 static void weaponRemoveBlast(void);
@@ -129,6 +130,7 @@ static void lanceAttack2(void);
 static void lanceAttack2Wait(void);
 static void lanceDestroyBridge(void);
 static void lanceFallout(void);
+static void lanceThrowFallout(void);
 static void lanceAttack3(void);
 static void fakeLanceDropInit(void);
 static void fakeLanceDropAppear(void);
@@ -1310,7 +1312,7 @@ static void invisibleDropWait()
 
 static void bridgeDestroyInit()
 {
-	Target *t = getTargetByName("GARGOYLE_MID_TARGET");
+	Target *t = getTargetByName("GARGOYLE_BOTTOM_TARGET");
 
 	setEntityAnimation(self, "LANCE_THROW_READY");
 
@@ -1350,35 +1352,19 @@ static void bridgeDestroyFollowPlayer()
 {
 	float target;
 
-	target = player.x - self->w / 2 + player.w / 2;
+	self->thinkTime--;
 
-	/* Move above the player */
-
-	if (fabs(target - self->x) <= fabs(self->dirX))
+	if (self->thinkTime <= 0)
 	{
-		self->targetY = self->y - self->h;
+		self->thinkTime = 0;
 
-		self->thinkTime = 15;
+		target = player.x - self->w / 2 + player.w / 2;
 
-		self->dirX = 0;
+		/* Move above the player */
 
-		if (player.y < getMapStartY() + SCREEN_HEIGHT)
+		if (fabs(target - self->x) <= fabs(self->dirX))
 		{
-			self->action = &bridgeDestroy;
-		}
-	}
-
-	else
-	{
-		self->dirX = self->speed;
-
-		self->x += target > self->x ? self->dirX : -self->dirX;
-
-		if (self->x < self->startX)
-		{
-			self->x = self->startX;
-
-			/* Throw if at the edge of the screen */
+			self->targetY = self->y - self->h;
 
 			self->thinkTime = 15;
 
@@ -1390,19 +1376,42 @@ static void bridgeDestroyFollowPlayer()
 			}
 		}
 
-		else if (self->x > self->endX)
+		else
 		{
-			self->x = self->endX;
+			self->dirX = self->speed;
 
-			/* Throw if at the edge of the screen */
+			self->x += target > self->x ? self->dirX : -self->dirX;
 
-			self->thinkTime = 15;
-
-			self->dirX = 0;
-
-			if (player.y < getMapStartY() + SCREEN_HEIGHT)
+			if (self->x < self->startX)
 			{
-				self->action = &bridgeDestroy;
+				self->x = self->startX;
+
+				/* Throw if at the edge of the screen */
+
+				self->thinkTime = 15;
+
+				self->dirX = 0;
+
+				if (player.y < getMapStartY() + SCREEN_HEIGHT)
+				{
+					self->action = &bridgeDestroy;
+				}
+			}
+
+			else if (self->x > self->endX)
+			{
+				self->x = self->endX;
+
+				/* Throw if at the edge of the screen */
+
+				self->thinkTime = 15;
+
+				self->dirX = 0;
+
+				if (player.y < getMapStartY() + SCREEN_HEIGHT)
+				{
+					self->action = &bridgeDestroy;
+				}
 			}
 		}
 	}
@@ -1546,8 +1555,6 @@ static void lanceThrow()
 			self->action = &lanceThrowWait;
 
 			self->thinkTime = 30;
-
-			self->maxThinkTime++;
 		}
 	}
 
@@ -1737,6 +1744,8 @@ static void lanceWait()
 		self->pain = &enemyPain;
 
 		self->touch = &entityTouch;
+		
+		self->fallout = &lanceThrowFallout;
 
 		self->action = &lanceDrop;
 	}
@@ -1792,9 +1801,9 @@ static void lanceFallout()
 		if (el->entity->inUse == TRUE && el->entity->type == WEAK_WALL && el->entity->mental == -1 &&
 			el->entity->touch != NULL && el->entity->x >= startX && el->entity->x < endX)
 		{
-			if (abs(el->entity->x - self->head->x) > distance)
+			if (fabsf(el->entity->x - self->head->x) > distance)
 			{
-				distance = abs(el->entity->x - self->head->x);
+				distance = fabsf(el->entity->x - self->head->x);
 
 				checkpointX = el->entity->x;
 			}
@@ -1813,6 +1822,16 @@ static void lanceFallout()
 	self->action = &lanceAttackTeleportFinish;
 }
 
+static void lanceThrowFallout()
+{
+	self->currentFrame = self->head->currentFrame;
+	self->frameTimer = self->head->frameTimer;
+
+	self->y = self->head->y + self->offsetY;
+
+	self->action = &lanceThrowTeleportFinish;
+}
+
 static void lanceDrop()
 {
 	if (self->standingOn != NULL || (self->flags & ON_GROUND))
@@ -1824,6 +1843,8 @@ static void lanceDrop()
 		setEntityAnimation(self, "LANCE_IN_GROUND");
 
 		playSoundToMap("sound/enemy/ground_spear/spear", -1, self->x, self->y, 0);
+		
+		self->head->maxThinkTime++;
 
 		switch (self->maxThinkTime)
 		{
@@ -1854,7 +1875,7 @@ static void lanceDie()
 
 	playSoundToMap("sound/enemy/centurion/centurion_die", -1, self->x, self->y, 0);
 
-	snprintf(name, sizeof(name), "%s_piece", self->name);
+	SNPRINTF(name, sizeof(name), "%s_piece", self->name);
 
 	for (i=0;i<6;i++)
 	{
@@ -2744,6 +2765,28 @@ static void lanceAttackTeleportFinish()
 	}
 }
 
+static void lanceThrowTeleportFinish()
+{
+	self->thinkTime--;
+
+	if (self->thinkTime <= 0)
+	{
+		self->flags &= ~(NO_DRAW|ATTACKING);
+
+		addParticleExplosion(self->x + self->w / 2, self->y + self->h / 2);
+
+		playSoundToMap("sound/common/spell", -1, self->x, self->y, 0);
+
+		self->touch = NULL;
+
+		self->action = &lanceWait;
+		
+		self->head->action = &lanceThrowInit;
+
+		self->mental = 0;
+	}
+}
+
 static void addStoneCoat()
 {
 	Entity *e = getFreeEntity();
@@ -3068,7 +3111,7 @@ static void addExitTrigger(Entity *e)
 {
 	char itemName[MAX_LINE_LENGTH];
 
-	snprintf(itemName, MAX_LINE_LENGTH, "\"%s\" 1 UPDATE_EXIT \"GARGOYLE_BOSS\"", e->objectiveName);
+	SNPRINTF(itemName, MAX_LINE_LENGTH, "\"%s\" 1 UPDATE_EXIT \"GARGOYLE_BOSS\"", e->objectiveName);
 
 	addGlobalTriggerFromScript(itemName);
 }
