@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2016 Parallel Realities
+Copyright (C) 2009-2024 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -296,7 +296,7 @@ static void createBody()
 		showErrorAndExit("Failed to allocate a whole %d bytes for Snake Boss body...", self->mental * (int)sizeof(Entity *));
 	}
 
-	snprintf(bodyName, sizeof(bodyName), "%s_body", self->name);
+	SNPRINTF(bodyName, sizeof(bodyName), "%s_body", self->name);
 
 	for (i=self->mental-1;i>=0;i--)
 	{
@@ -967,7 +967,7 @@ static void fallToGround()
 
 	if (self->flags & ON_GROUND)
 	{
-		playSoundToMap("sound/common/crash", BOSS_CHANNEL, self->x, self->y, 0);
+		playSoundToMap("sound/common/crash", -1, self->x, self->y, 0);
 
 		setEntityAnimation(self, "PAIN");
 
@@ -1185,7 +1185,7 @@ static void addSmokeAlongBody()
 
 	shakeScreen(MEDIUM, 15);
 
-	bodyLength = abs(self->endX - self->x);
+	bodyLength = (int)fabsf(self->endX - self->x);
 
 	for (i=0;i<100;i++)
 	{
