@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2016 Parallel Realities
+Copyright (C) 2009-2024 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -19,4 +19,4 @@ Foundation, 51 Franklin Street, Suite 500, Boston, MA 02110-1335, USA.
 
 Entity *addSorceror(int, int, char *);
 int drawDisintegrationSpell(void);
-void drawDisintegrationLine(int, int, int, int, int, int, int);
+void drawDisintegrationLine(int, int, int, int, Colour, Colour, Colour);
