@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2016 Parallel Realities
+Copyright (C) 2009-2024 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -40,10 +40,6 @@ Foundation, 51 Franklin Street, Suite 500, Boston, MA 02110-1335, USA.
 
 #define JUMP_HEIGHT 12
 
-#define TRANS_R 127
-#define TRANS_G 255
-#define TRANS_B 127
-
 #define MAX_ANIMATIONS 1024
 
 #define MAX_ENTITIES 1024
@@ -52,6 +48,8 @@ Foundation, 51 Franklin Street, Suite 500, Boston, MA 02110-1335, USA.
 
 #define MAX_SCRIPT_WIDTH 380
 
+#define TEXTURE_CACHE_TIME 18000
+
 #define BLANK_TILE 0
 
 #define SOLID_TILE_START 1
@@ -154,6 +152,8 @@ Foundation, 51 Franklin Street, Suite 500, Boston, MA 02110-1335, USA.
 
 #define STRNCPY(dest, src, n) strncpy(dest, src, n); dest[n - 1] = '\0'
 
+#define SNPRINTF(dest, size, format, ...) if (snprintf(dest, size, format, __VA_ARGS__) > size) printf("Warning: Buffer too small for %s\n", dest)
+
 #define SWORD_MAX_CHARGE 50
 
 #if DEV == 1
@@ -226,7 +226,7 @@ Foundation, 51 Franklin Street, Suite 500, Boston, MA 02110-1335, USA.
 
 #define TABLE_SIZE 255
 
-#define YEAR 2016
+#define YEAR 2024
 
 #ifdef TRUE
 	#undef TRUE
