@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2016 Parallel Realities
+Copyright (C) 2009-2024 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -23,6 +23,7 @@ Foundation, 51 Franklin Street, Suite 500, Boston, MA 02110-1335, USA.
 #include "game.h"
 #include "graphics/font.h"
 #include "graphics/graphics.h"
+#include "graphics/texture_cache.h"
 #include "input.h"
 #include "system/error.h"
 
@@ -50,17 +51,63 @@ void createAutoDialogBox(char *title, char *text, int thinkTime)
 	dialogBox.thinkTime = thinkTime;
 }
 
-SDL_Surface *createDialogBox(char *title, char *msg)
+Texture *createDialogBox(char *title, char *msg)
 {
-	char *text, *token, word[MAX_VALUE_LENGTH], *savePtr, *titleText;
+	char *text, *token, word[MAX_VALUE_LENGTH], *savePtr, *titleText, *playTime, *cachedText;
 	int i, lines, w, h, maxWidth, lineBreak, *lineBreaks;
 	SDL_Surface **surface, *tempSurface;
+	Texture *texture;
 	SDL_Rect dest;
 
 	savePtr = NULL;
 
 	freeDialogBox();
 
+	if (strstr(msg, "[") == NULL)
+	{
+        if (title != NULL)
+        {
+            i = strlen(title) + strlen(msg) + 1;
+            
+            cachedText = malloc(i);
+            
+            if (cachedText == NULL)
+            {
+                showErrorAndExit("Failed to allocate a whole %d bytes for the Dialog Text", i);
+            }
+            
+            SNPRINTF(cachedText, i, "%s%s", title, msg);
+        }
+        
+        else
+        {
+            i = strlen(msg) + 1;
+            
+            cachedText = malloc(i);
+            
+            if (cachedText == NULL)
+            {
+                showErrorAndExit("Failed to allocate a whole %d bytes for the Dialog Text", i);
+            }
+            
+            SNPRINTF(cachedText, i, "%s", msg);
+        }
+        
+		texture = getTextureFromCache(cachedText);
+
+		if (texture != NULL)
+		{
+            free(cachedText);
+            
+			return texture;
+		}
+	}
+	
+	else
+    {
+        cachedText = NULL;
+    }
+
 	text = malloc(strlen(msg) + 1);
 
 	if (text == NULL)
@@ -114,11 +161,11 @@ SDL_Surface *createDialogBox(char *title, char *msg)
 		lines++;
 	}
 
-	surface = malloc(sizeof(SDL_Surface *) * lines);
+	surface = malloc(sizeof(SDL_Texture *) * lines);
 
 	if (surface == NULL)
 	{
-		showErrorAndExit("Failed to allocate a whole %d bytes for the Dialog Surfaces", (int)sizeof(SDL_Surface *) * lines);
+		showErrorAndExit("Failed to allocate a whole %d bytes for the Dialog Surfaces", (int)sizeof(SDL_Texture *) * lines);
 	}
 
 	lineBreaks = malloc(sizeof(int) * lines);
@@ -151,13 +198,17 @@ SDL_Surface *createDialogBox(char *title, char *msg)
 	{
 		lineBreak = FALSE;
 
-		snprintf(word, sizeof(word), "%d", game.kills);
+		SNPRINTF(word, sizeof(word), "%d", game.kills);
 
 		token = replaceString(token, "[GAME_KILLS]", word);
+		
+		playTime = getPlayTimeHours();
 
-		token = replaceString(token, "[HOURS]", getPlayTimeHours());
+		token = replaceString(token, "[HOURS]", playTime);
+		
+		free(playTime);
 
-		snprintf(word, sizeof(word), "%d", game.continues);
+		SNPRINTF(word, sizeof(word), "%d", game.continues);
 
 		token = replaceString(token, "[CONTINUE_COUNT]", word);
 
@@ -181,7 +232,7 @@ SDL_Surface *createDialogBox(char *title, char *msg)
 
 		token = replaceString(token, "[INPUT_NEXT]", getKeyValue(control.button[CONTROL_NEXT]));
 
-		snprintf(word, sizeof(word), "%s ", token);
+		SNPRINTF(word, sizeof(word), "%s ", token);
 
 		if (word[strlen(word) - 2] == '\n')
 		{
@@ -232,7 +283,7 @@ SDL_Surface *createDialogBox(char *title, char *msg)
 
 	h -= 5;
 
-	tempSurface = createSurface(maxWidth, h);
+	tempSurface = createSurface(maxWidth, h, FALSE);
 
 	w = h = 0;
 
@@ -264,7 +315,14 @@ SDL_Surface *createDialogBox(char *title, char *msg)
 		}
 	}
 
-	tempSurface = addBorder(tempSurface, 255, 255, 255, 0, 0, 0);
+	texture = addBorder(tempSurface, 255, 255, 255, 0, 0, 0);
+
+    if (cachedText != NULL)
+    {
+        addTextureToCache(cachedText, texture, FALSE);
+        
+        free(cachedText);
+    }
 
 	free(surface);
 
@@ -277,7 +335,7 @@ SDL_Surface *createDialogBox(char *title, char *msg)
 
 	free(lineBreaks);
 
-	return tempSurface;
+	return texture;
 }
 
 void doDialogBox()
@@ -305,8 +363,6 @@ void freeDialogBox()
 {
 	if (dialogBox.dialogSurface != NULL)
 	{
-		SDL_FreeSurface(dialogBox.dialogSurface);
-
 		dialogBox.dialogSurface = NULL;
 
 		dialogBox.thinkTime = 0;
@@ -329,7 +385,7 @@ static char *replaceString(char *string, char *find, char *replace)
 
 	buffer[p - string] = '\0';
 
-	snprintf(buffer + (p - string), MAX_VALUE_LENGTH, "%s%s", replace, p + strlen(find));
+	SNPRINTF(buffer + (p - string), MAX_VALUE_LENGTH, "%s%s", replace, p + strlen(find));
 
 	return buffer;
 }
