@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2016 Parallel Realities
+Copyright (C) 2009-2024 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -26,6 +26,7 @@ Foundation, 51 Franklin Street, Suite 500, Boston, MA 02110-1335, USA.
 #include "game.h"
 #include "graphics/decoration.h"
 #include "graphics/graphics.h"
+#include "graphics/texture_cache.h"
 #include "hud.h"
 #include "inventory.h"
 #include "map.h"
@@ -59,7 +60,7 @@ void draw()
 			break;
 
 			case IN_INVENTORY:
-				SDL_SetClipRect(game.screen, NULL);
+				SDL_RenderSetClipRect(game.renderer, NULL);
 
 				showPauseDialog();
 
@@ -105,12 +106,12 @@ void draw()
 
 						rect.w = rect.h = spotlightSize();
 
-						SDL_SetClipRect(game.screen, &rect);
+						SDL_RenderSetClipRect(game.renderer, &rect);
 					}
 
 					else
 					{
-						SDL_SetClipRect(game.screen, NULL);
+						SDL_RenderSetClipRect(game.renderer, NULL);
 					}
 
 					/* Draw the background */
@@ -159,7 +160,7 @@ void draw()
 
 						drawSpotlight(clipX, clipY);
 
-						SDL_SetClipRect(game.screen, NULL);
+						SDL_RenderSetClipRect(game.renderer, NULL);
 					}
 
 					/* Draw the hud */
@@ -183,26 +184,32 @@ void draw()
 
 						if (player.face == LEFT)
 						{
-							snprintf(text, sizeof(text), "%3d : %3d", (int)player.x, (int)player.y);
+							SNPRINTF(text, sizeof(text), "%3d : %3d", (int)player.x, (int)player.y);
 						}
 
 						else
 						{
-							snprintf(text, sizeof(text), "%3d : %3d", (int)player.x, (int)player.y);
+							SNPRINTF(text, sizeof(text), "%3d : %3d", (int)player.x, (int)player.y);
 						}
 					#endif
+
+					if (scriptRunning() == FALSE && (game.frames % 600 == 0))
+					{
+						checkTextureCache();
+					}
 				}
 			break;
 		}
-
-		#if DEV == 1
-			takeScreenshot();
-		#endif
+		
+		if (game.frames % 300 == 0)
+		{
+			removeUnreferencedEntities();
+		}
 	}
 
 	else
 	{
-		SDL_SetClipRect(game.screen, NULL);
+		SDL_RenderSetClipRect(game.renderer, NULL);
 
 		showPauseDialog();
 
@@ -211,7 +218,7 @@ void draw()
 
 	/* Swap the buffers */
 
-	SDL_Flip(game.screen);
+	SDL_RenderPresent(game.renderer);
 
 	/* Sleep briefly */
 
