@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2016 Parallel Realities
+Copyright (C) 2009-2024 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -931,7 +931,7 @@ static void iceDrop()
 
 	checkToMap(self);
 
-	if (self->flags & ON_GROUND)
+	if ((self->flags & ON_GROUND) || self->standingOn != NULL)
 	{
 		playSoundToMap("sound/common/shatter", -1, self->x, self->y, 0);
 
@@ -1076,9 +1076,17 @@ static void createIceBlock()
 
 static void iceBlockDrop()
 {
-	if (self->standingOn != NULL && strcmpignorecase(self->name, self->standingOn->name) == 0)
+	if (self->standingOn != NULL)
 	{
-		self->standingOn->action = self->standingOn->die;
+		if (strcmpignorecase(self->name, self->standingOn->name) == 0)
+		{
+			self->standingOn->action = self->standingOn->die;
+		}
+
+		else
+		{
+			self->die();
+		}
 	}
 
 	self->thinkTime--;
@@ -2058,7 +2066,7 @@ static void followPlayer()
 		hover();
 	}
 
-	else if (abs(self->x - self->targetX) <= abs(self->dirX))
+	else if (fabsf(self->x - self->targetX) <= fabsf(self->dirX))
 	{
 		self->x = self->targetX;
 
