@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2016 Parallel Realities
+Copyright (C) 2009-2024 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -38,6 +38,7 @@ Foundation, 51 Franklin Street, Suite 500, Boston, MA 02110-1335, USA.
 #include "system/random.h"
 #include "system/resources.h"
 
+extern Entity player;
 extern Entity *self;
 extern Game game;
 
@@ -253,8 +254,8 @@ void doEntities()
 
 void drawEntities(int depth)
 {
-	int i, drawn, removeCount;
-	EntityList *el, *prev, *el2;
+	int i, drawn;
+	EntityList *el;
 
 	/* Draw standard entities */
 
@@ -317,45 +318,6 @@ void drawEntities(int depth)
 			}
 		}
 	}
-
-	if (game.frames % 300 == 0)
-	{
-		removeCount = 0;
-
-		prev = entities;
-
-		for (el=entities->next;el!=NULL;el=el2)
-		{
-			el2 = el->next;
-
-			if (el->entity->inUse == FALSE && isReferenced(el->entity) == FALSE)
-			{
-				prev->next = el2;
-
-				removeCount++;
-
-				free(el->entity);
-
-				el->entity = NULL;
-
-				free(el);
-
-				el = NULL;
-			}
-
-			else
-			{
-				prev = prev->next;
-			}
-		}
-
-		#if DEV == 1
-		if (removeCount != 0)
-		{
-			printf("Removed %d entities taking up %d bytes\n", removeCount, (int)sizeof(Entity) * removeCount);
-		}
-		#endif
-	}
 }
 
 void removeEntity()
@@ -368,6 +330,95 @@ void removeEntity()
 	}
 }
 
+void removeAllSpawnedIn()
+{
+	Entity *e;
+	EntityList *el;
+
+	for (el=entities->next;el!=NULL;el=el->next)
+	{
+		e = el->entity;
+
+		if (e->inUse == TRUE && (e->flags & SPAWNED_IN))
+		{
+			/* Teleport expired enemies beneath the map */
+
+			if (e->health != 0)
+			{
+				e->y = (MAX_MAP_Y + 1) * TILE_SIZE;
+
+				e->action = &entityDieNoDrop;
+			}
+		}
+	}
+}
+
+void removeUnreferencedEntities()
+{
+	int removeCount;
+	EntityList *el, *prev, *el2;
+	
+	removeCount = 0;
+
+	prev = entities;
+
+	for (el=entities->next;el!=NULL;el=el2)
+	{
+		el2 = el->next;
+
+		if (el->entity->inUse == FALSE && isReferenced(el->entity) == FALSE)
+		{
+			prev->next = el2;
+
+			removeCount++;
+
+			free(el->entity);
+
+			el->entity = NULL;
+
+			free(el);
+
+			el = NULL;
+		}
+
+		else
+		{
+			prev = prev->next;
+		}
+	}
+
+	#if DEV == 1
+	if (removeCount != 0)
+	{
+		printf("Removed %d entities taking up %d bytes\n", removeCount, (int)sizeof(Entity) * removeCount);
+	}
+	#endif
+}
+
+void disableSpawners(int disable)
+{
+	Entity *e;
+	EntityList *el;
+
+	for (el=entities->next;el!=NULL;el=el->next)
+	{
+		e = el->entity;
+
+		if (e->inUse == TRUE && e->type == SPAWNER)
+		{
+			if (disable == TRUE)
+			{
+				e->flags |= HELPLESS;
+			}
+
+			else
+			{
+				e->flags &= ~HELPLESS;
+			}
+		}
+	}
+}
+
 void doNothing()
 {
 	self->thinkTime--;
@@ -421,6 +472,10 @@ void doNothing()
 
 	if (self->environment == WATER && (self->flags & FLOATS))
 	{
+		self->y = getWaterTop(self->x, self->y);
+		
+		self->y = self->y - TILE_SIZE;
+		
 		self->action = &floatLeftToRight;
 
 		self->endX = self->dirX = 1.0;
@@ -508,6 +563,17 @@ void floatLeftToRight()
 	}
 }
 
+void syncBoulderFrameSpeed()
+{
+	float distancePerRevolution = self->w;
+
+	distancePerRevolution *= PI;
+
+	distancePerRevolution /= getFrameCount(self) + 1;
+
+	self->frameSpeed = fabs(self->dirX) / distancePerRevolution;
+}
+
 void entityDie()
 {
 	self->damage = 0;
@@ -1601,7 +1667,7 @@ static void scriptEntityMoveToTarget()
 		showErrorAndExit("%s has a speed of 0 and will not move!", self->objectiveName);
 	}
 
-	if (abs(self->x - self->targetX) > self->speed)
+	if (fabsf(self->x - self->targetX) > self->speed)
 	{
 		self->dirX = (self->x < self->targetX ? self->speed : -self->speed);
 	}
@@ -1616,7 +1682,7 @@ static void scriptEntityMoveToTarget()
 		self->targetY = self->y;
 	}
 
-	if (abs(self->y - self->targetY) > self->speed)
+	if (fabsf(self->y - self->targetY) > self->speed)
 	{
 		self->dirY = (self->y < self->targetY ? self->speed : -self->speed);
 	}
@@ -1681,7 +1747,7 @@ static void entityMoveToTarget()
 		showErrorAndExit("%s has a speed of 0 and will not move!", self->objectiveName);
 	}
 
-	if (abs(self->x - self->targetX) > self->speed)
+	if (fabsf(self->x - self->targetX) > self->speed)
 	{
 		self->dirX = (self->x < self->targetX ? self->speed : -self->speed);
 	}
@@ -1698,7 +1764,7 @@ static void entityMoveToTarget()
 		self->targetY = self->y;
 	}
 
-	if (abs(self->y - self->targetY) > self->speed)
+	if (fabsf(self->y - self->targetY) > self->speed)
 	{
 		self->dirY = (self->y < self->targetY ? self->speed : -self->speed);
 	}
@@ -1778,7 +1844,7 @@ void doTeleport()
 	float speed;
 	Entity *e;
 
-	if (abs(self->x - self->targetX) < TELEPORT_SPEED && abs(self->y - self->targetY) < TELEPORT_SPEED)
+	if (fabsf(self->x - self->targetX) < TELEPORT_SPEED && fabsf(self->y - self->targetY) < TELEPORT_SPEED)
 	{
 		self->flags &= ~(NO_DRAW|HELPLESS|TELEPORTING);
 
@@ -2006,7 +2072,7 @@ void addDuplicateImage(Entity *e)
 
 	duplicate->creditsAction = &duplicateWait;
 
-	snprintf(shadowAnim, MAX_VALUE_LENGTH, "%s_SHADOW", getAnimationTypeAtIndex(e));
+	SNPRINTF(shadowAnim, MAX_VALUE_LENGTH, "%s_SHADOW", getAnimationTypeAtIndex(e));
 
 	setEntityAnimation(duplicate, shadowAnim);
 
@@ -2050,5 +2116,10 @@ static int isReferenced(Entity *e)
 		}
 	}
 
+	if (player.head == e || player.target == e || player.standingOn == e)
+	{
+		return TRUE;
+	}
+
 	return FALSE;
 }
