@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2016 Parallel Realities
+Copyright (C) 2009-2024 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -23,6 +23,9 @@ Entity *getFreeEntity(void);
 void doEntities(void);
 void drawEntities(int);
 void removeEntity(void);
+void removeAllSpawnedIn(void);
+void removeUnreferencedEntities(void);
+void disableSpawners(int);
 void doNothing(void);
 void entityDie(void);
 void standardDie(void);
@@ -41,6 +44,7 @@ void writeEntitiesToFile(FILE *);
 void floatLeftToRight(void);
 void moveLeftToRight(void);
 void flyLeftToRight(void);
+void syncBoulderFrameSpeed(void);
 void addEntityFromScript(char *);
 void entityWalkTo(Entity *, char *);
 void entityWalkToRelative(Entity *, char *);
