@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2016 Parallel Realities
+Copyright (C) 2009-2024 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -170,7 +170,7 @@ void fireGlobalTrigger(char *name)
 
 			if (trigger[i].targetType == UPDATE_OBJECTIVE)
 			{
-				snprintf(message, MAX_MESSAGE_LENGTH, "%s (%d / %d)", _(trigger[i].targetName), trigger[i].count, trigger[i].total);
+				SNPRINTF(message, MAX_MESSAGE_LENGTH, "%s (%d / %d)", _(trigger[i].targetName), trigger[i].count, trigger[i].total);
 
 				freeMessageQueue();
 
@@ -257,11 +257,11 @@ void updateGlobalTrigger(char *name, int value)
 	}
 }
 
-SDL_Surface *listObjectives()
+Texture *listObjectives()
 {
 	int i;
 	char message[MAX_MESSAGE_LENGTH], *allMessages;
-	SDL_Surface *image;
+	Texture *image;
 
 	allMessages = malloc(MAX_MESSAGE_LENGTH * MAX_TRIGGERS);
 
@@ -278,12 +278,12 @@ SDL_Surface *listObjectives()
 		{
 			if (trigger[i].total > 1)
 			{
-				snprintf(message, MAX_MESSAGE_LENGTH, "%s (%d / %d)\n ", _(trigger[i].targetName), trigger[i].count, trigger[i].total);
+				SNPRINTF(message, MAX_MESSAGE_LENGTH, "%s (%d / %d)\n ", _(trigger[i].targetName), trigger[i].count, trigger[i].total);
 			}
 
 			else
 			{
-				snprintf(message, MAX_MESSAGE_LENGTH, "%s\n ", _(trigger[i].targetName));
+				SNPRINTF(message, MAX_MESSAGE_LENGTH, "%s\n ", _(trigger[i].targetName));
 			}
 
 			strncat(allMessages, message, (MAX_MESSAGE_LENGTH * MAX_TRIGGERS) - strlen(allMessages) - 1);
