@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2016 Parallel Realities
+Copyright (C) 2009-2024 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -23,5 +23,5 @@ void fireGlobalTrigger(char *);
 void writeGlobalTriggersToFile(FILE *);
 void addGlobalTriggerFromScript(char *);
 void updateGlobalTrigger(char *, int);
-SDL_Surface *listObjectives(void);
+Texture *listObjectives(void);
 void removeGlobalTrigger(char *);
