@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2016 Parallel Realities
+Copyright (C) 2009-2024 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -69,7 +69,7 @@ void runScript(char *name)
 
 	savePtr = NULL;
 
-	snprintf(filename, sizeof(filename), "data/scripts/%s.dat", name);
+	SNPRINTF(filename, sizeof(filename), "data/scripts/%s.dat", name);
 
 	buffer = loadFileFromPak(filename);
 
@@ -1018,6 +1018,18 @@ void readNextScriptLine()
 			script.thinkTime = atoi(token);
 		}
 
+		else if (strcmpignorecase("REMOVE_ALL_SPAWNED_IN", command) == 0)
+		{
+			removeAllSpawnedIn();
+		}
+
+		else if (strcmpignorecase("DISABLE_SPAWNERS", command) == 0)
+		{
+			token = strtok_r(NULL, "\0", &savePtr);
+
+			disableSpawners(atoi(token));
+		}
+
 		else if (strcmpignorecase("PLAY_SOUND", command) == 0)
 		{
 			token = strtok_r(NULL, "\0", &savePtr);
@@ -1462,6 +1474,11 @@ void readNextScriptLine()
 	}
 }
 
+int scriptRunning()
+{
+	return script.lineCount != 0;
+}
+
 int scriptWaiting()
 {
 	return (script.thinkTime != 0 || script.counter != 0);
