@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2016 Parallel Realities
+Copyright (C) 2009-2024 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -19,6 +19,9 @@ Foundation, 51 Franklin Street, Suite 500, Boston, MA 02110-1335, USA.
 
 #include "../headers.h"
 
+#include "../init.h"
+#include "graphics.h"
+
 #include <png.h>
 
 /*
@@ -37,7 +40,7 @@ static void writeData(char *name, png_bytep *rows, int w, int h, int colourtype,
 	{
 		printf("Could not save %s\n", name);
 
-		exit(1);
+		cleanup(1);
 	}
 
 	pngPtr = png_create_write_struct(PNG_LIBPNG_VER_STRING, NULL, NULL, NULL);
@@ -46,7 +49,7 @@ static void writeData(char *name, png_bytep *rows, int w, int h, int colourtype,
 	{
 		printf("Failed to create PNG structure");
 
-		exit(1);
+		cleanup(1);
 	}
 
 	infoPtr = png_create_info_struct(pngPtr);
@@ -55,14 +58,14 @@ static void writeData(char *name, png_bytep *rows, int w, int h, int colourtype,
 	{
 		printf("Failed to create PNG info");
 
-		exit(1);
+		cleanup(1);
 	}
 
 	if (setjmp(png_jmpbuf(pngPtr)) != 0)
 	{
 		printf("PNG Jump point failed\n");
 
-		exit(1);
+		cleanup(1);
 	}
 
 	png_init_io(pngPtr, fp);
@@ -75,6 +78,8 @@ static void writeData(char *name, png_bytep *rows, int w, int h, int colourtype,
 
 	png_write_end(pngPtr, NULL);
 
+	png_destroy_write_struct(&pngPtr, &infoPtr);
+
 	fclose(fp);
 }
 
@@ -86,11 +91,6 @@ void savePNG(SDL_Surface *surface, char *name)
 	SDL_Surface *temp;
 	SDL_Rect ss_rect;
 	int i;
-	int alpha = 0;
-	int pixel_bits = 32;
-
-	unsigned surf_flags;
-	unsigned surf_alpha;
 
 	ss_rows = 0;
 	ss_size = 0;
@@ -99,44 +99,7 @@ void savePNG(SDL_Surface *surface, char *name)
 	ss_w = surface->w;
 	ss_h = surface->h;
 
-	if (surface->format->Amask)
-	{
-		alpha = 1;
-		pixel_bits = 32;
-	}
-
-	else
-	{
-		pixel_bits = 24;
-	}
-
-	temp = SDL_CreateRGBSurface(SDL_HWSURFACE|SDL_SRCALPHA, ss_w, ss_h, pixel_bits,
-		#if SDL_BYTEORDER == SDL_BIG_ENDIAN
-			0xff0000, 0xff00, 0xff, 0x000000ff
-		#else
-			0xff, 0xff00, 0xff0000, 0xff000000
-		#endif
-		);
-
-	if (temp == NULL)
-	{
-		printf("Error creating PNG surface\n");
-
-		exit(1);
-	}
-
-	surf_flags = surface->flags & (SDL_SRCALPHA | SDL_SRCCOLORKEY);
-	surf_alpha = surface->format->alpha;
-
-	if (surf_flags & SDL_SRCALPHA)
-	{
-		SDL_SetAlpha(surface, 0, 255);
-	}
-
-	if (surf_flags & SDL_SRCCOLORKEY)
-	{
-		SDL_SetColorKey(surface, 0, surface->format->colorkey);
-	}
+	temp = createSurface(surface->w, surface->h, FALSE);
 
 	ss_rect.x = 0;
 	ss_rect.y = 0;
@@ -154,33 +117,16 @@ void savePNG(SDL_Surface *surface, char *name)
 		{
 			printf("Ran out of memory when creating PNG rows\n");
 
-			exit(1);
+			cleanup(1);
 		}
 	}
 
-	if (surf_flags & SDL_SRCALPHA)
-	{
-		SDL_SetAlpha(surface, SDL_SRCALPHA, (Uint8)surf_alpha);
-	}
-
-	if (surf_flags & SDL_SRCCOLORKEY)
-	{
-		SDL_SetColorKey(surface, SDL_SRCCOLORKEY, surface->format->colorkey);
-	}
-
 	for (i = 0; i < ss_h; i++)
 	{
 		ss_rows[i] = ((unsigned char*)temp->pixels) + i * temp->pitch;
 	}
 
-	if (alpha)
-	{
-		writeData(name, ss_rows, surface->w, surface->h, PNG_COLOR_TYPE_RGB_ALPHA, 8);
-	}
-	else
-	{
-		writeData(name, ss_rows, surface->w, surface->h, PNG_COLOR_TYPE_RGB, 8);
-	}
+	writeData(name, ss_rows, surface->w, surface->h, PNG_COLOR_TYPE_RGB_ALPHA, 8);
 
 	free(ss_rows);
 
