@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2016 Parallel Realities
+Copyright (C) 2009-2024 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -22,6 +22,7 @@ Foundation, 51 Franklin Street, Suite 500, Boston, MA 02110-1335, USA.
 #include "audio/audio.h"
 #include "graphics/font.h"
 #include "graphics/graphics.h"
+#include "graphics/texture_cache.h"
 #include "hud.h"
 #include "inventory.h"
 #include "medal.h"
@@ -38,9 +39,15 @@ static void getNextMessageFromQueue(void);
 
 void initHud()
 {
+	SDL_Surface *heart;
+	
 	hud.itemBox = loadImage("gfx/hud/item_box.png");
 
-	hud.heart = loadImage("gfx/hud/heart.png");
+	heart = loadImageAsSurface("gfx/hud/heart.png");
+	
+	hud.heart = convertSurfaceToTexture(heart, FALSE);
+	
+	hud.whiteHeart = convertImageToWhite(heart, TRUE);
 
 	hud.emptyHeart = loadImage("gfx/hud/heart_empty.png");
 
@@ -80,7 +87,7 @@ void doHud()
 	{
 		if (hud.medalTextSurface != NULL)
 		{
-			SDL_FreeSurface(hud.medalTextSurface);
+			destroyTexture(hud.medalTextSurface);
 
 			hud.medalTextSurface = NULL;
 
@@ -96,8 +103,6 @@ void doHud()
 	{
 		if (hud.infoMessage.surface != NULL)
 		{
-			SDL_FreeSurface(hud.infoMessage.surface);
-
 			hud.infoMessage.surface = NULL;
 
 			hud.infoMessage.text[0] = '\0';
@@ -133,9 +138,11 @@ void doHud()
 void drawHud()
 {
 	char quantity[4];
+	char cacheName[10];
 	int i, x, y, h, w, itemBoxMid, quant;
 	float percentage, clipWidth;
 	Entity *e;
+	SDL_Surface *quantitySurface;
 
 	if (game.showHUD == TRUE)
 	{
@@ -143,17 +150,17 @@ void drawHud()
 
 		if (game.status == IN_INVENTORY)
 		{
-			drawBox(game.screen, itemBoxMid, 15, hud.itemBox->w, hud.itemBox->h, 0, 0, 0);
+			drawBox(itemBoxMid, 15, hud.itemBox->w, hud.itemBox->h, 0, 0, 0, 255);
 		}
 
 		drawSelectedInventoryItem(itemBoxMid, 15, hud.itemBox->w, hud.itemBox->h);
 
 		drawImage(hud.itemBox, itemBoxMid, 15, FALSE, 255);
+		
+		x = FALSE;
 
 		if (playerWeapon.inUse == TRUE)
 		{
-			x = FALSE;
-
 			if (strcmpignorecase(playerWeapon.name, "weapon/bow") == 0)
 			{
 				e = getInventoryItemByObjectiveName(playerWeapon.requires);
@@ -180,23 +187,31 @@ void drawHud()
 					quant = 0;
 				}
 
-				if (hud.quantity != quant)
+				if (hud.quantity != quant || (game.frames % (TEXTURE_CACHE_TIME / 2)) == 0)
 				{
-					if (hud.quantitySurface != NULL)
+					SNPRINTF(quantity, 4, "%d", quant);
+
+					SNPRINTF(cacheName, 10, "hud_%d", quant);
+
+					hud.quantitySurface = getTextureFromCache(cacheName);
+
+					if (hud.quantitySurface == NULL)
 					{
-						SDL_FreeSurface(hud.quantitySurface);
+						quantitySurface = generateTransparentTextSurface(quantity, game.font, 255, 255, 255, FALSE);
+
+						hud.quantitySurface = convertSurfaceToTexture(quantitySurface, TRUE);
+
+						addTextureToCache(cacheName, hud.quantitySurface, FALSE);
 					}
-
-					snprintf(quantity, 4, "%d", quant);
-
-					hud.quantitySurface = generateTransparentTextSurface(quantity, game.font, 255, 255, 255, FALSE);
+					
+					hud.quantity = quant;
 				}
 
 				drawImage(hud.quantitySurface, (SCREEN_WIDTH - hud.quantitySurface->w) / 2, 15 + hud.itemBox->h + 5, FALSE, 255);
 			}
 		}
 
-		else
+		if (x == FALSE)
 		{
 			hud.quantity = -1;
 		}
@@ -254,7 +269,15 @@ void drawHud()
 
 			if (i < player.health)
 			{
-				drawImage(hud.heart, w, h, (player.health <= 3 && hud.thinkTime <= 30), 255);
+				if (player.health <= 3 && hud.thinkTime <= 30)
+				{
+					drawImage(hud.whiteHeart, w, h, FALSE, 255);
+				}
+				
+				else
+				{
+					drawImage(hud.heart, w, h, FALSE, 255);
+				}
 			}
 
 			drawImage(hud.emptyHeart, w, h, FALSE, 255);
@@ -285,58 +308,51 @@ void freeHud()
 
 	if (hud.itemBox != NULL)
 	{
-		SDL_FreeSurface(hud.itemBox);
+		destroyTexture(hud.itemBox);
 
 		hud.itemBox = NULL;
 	}
 
 	if (hud.heart != NULL)
 	{
-		SDL_FreeSurface(hud.heart);
+		destroyTexture(hud.heart);
 
 		hud.heart = NULL;
 	}
 
 	if (hud.emptyHeart != NULL)
 	{
-		SDL_FreeSurface(hud.emptyHeart);
+		destroyTexture(hud.emptyHeart);
 
 		hud.emptyHeart = NULL;
 	}
 
 	if (hud.spotlight != NULL)
 	{
-		SDL_FreeSurface(hud.spotlight);
+		destroyTexture(hud.spotlight);
 
 		hud.spotlight = NULL;
 	}
 
 	if (hud.infoMessage.surface != NULL)
 	{
-		SDL_FreeSurface(hud.infoMessage.surface);
-
 		hud.infoMessage.surface = NULL;
 	}
 
 	if (hud.medalTextSurface != NULL)
 	{
-		SDL_FreeSurface(hud.medalTextSurface);
+		destroyTexture(hud.medalTextSurface);
 
 		hud.medalTextSurface = NULL;
 	}
 
-	if (hud.quantitySurface != NULL)
-	{
-		SDL_FreeSurface(hud.quantitySurface);
-
-		hud.quantitySurface = NULL;
-	}
+	hud.quantitySurface = NULL;
 
 	for (i=0;i<4;i++)
 	{
 		if (hud.medalSurface[i] != NULL)
 		{
-			SDL_FreeSurface(hud.medalSurface[i]);
+			destroyTexture(hud.medalSurface[i]);
 
 			hud.medalSurface[i] = NULL;
 		}
@@ -344,29 +360,24 @@ void freeHud()
 
 	if (hud.disabledMedalSurface != NULL)
 	{
-		SDL_FreeSurface(hud.disabledMedalSurface);
+		destroyTexture(hud.disabledMedalSurface);
 
 		hud.disabledMedalSurface = NULL;
 	}
 
-	if (hud.slimeTimerSurface != NULL)
-	{
-		SDL_FreeSurface(hud.slimeTimerSurface);
-
-		hud.slimeTimerSurface = NULL;
-	}
+	hud.slimeTimerSurface = NULL;
 
 	freeMessageQueue();
 }
 
 void setSlimeTimerValue(int value)
 {
+	SDL_Surface *slimeTimerSurface;
+
 	char timeValue[5];
 
 	if (hud.slimeTimerSurface != NULL || value < 0)
 	{
-		SDL_FreeSurface(hud.slimeTimerSurface);
-
 		hud.slimeTimerSurface = NULL;
 
 		if (value < 0)
@@ -375,11 +386,18 @@ void setSlimeTimerValue(int value)
 		}
 	}
 
-	snprintf(timeValue, 5, "%d", value);
+	SNPRINTF(timeValue, 5, "%d", value);
 
-	hud.slimeTimerSurface = generateTextSurface(timeValue, game.font, 220, 220, 220, 0, 0, 0);
+	hud.slimeTimerSurface = getTextureFromCache(timeValue);
 
-	hud.slimeTimerSurface = addBorder(hud.slimeTimerSurface, 255, 255, 255, 0, 0, 0);
+	if (hud.slimeTimerSurface == NULL)
+	{
+		slimeTimerSurface = generateTextSurface(timeValue, game.font, 220, 220, 220, 0, 0, 0);
+
+		hud.slimeTimerSurface = addBorder(slimeTimerSurface, 255, 255, 255, 0, 0, 0);
+
+		addTextureToCache(timeValue, hud.slimeTimerSurface, FALSE);
+	}
 }
 
 void setInfoBoxMessage(int thinkTime, int r, int g, int b, char *fmt, ...)
@@ -433,6 +451,7 @@ static void addMessageToQueue(char *text, int thinkTime, int r, int g, int b)
 static void getNextMessageFromQueue()
 {
 	Message *head = messageHead.next;
+	SDL_Surface *infoSurface;
 
 	if (head != NULL)
 	{
@@ -442,17 +461,17 @@ static void getNextMessageFromQueue()
 		hud.infoMessage.g = head->g;
 		hud.infoMessage.b = head->b;
 
-		if (hud.infoMessage.surface != NULL)
+		hud.infoMessage.surface = getTextureFromCache(hud.infoMessage.text);
+
+		if (hud.infoMessage.surface == NULL)
 		{
-			SDL_FreeSurface(hud.infoMessage.surface);
+			infoSurface = generateTextSurface(hud.infoMessage.text, game.font, hud.infoMessage.r, hud.infoMessage.g, hud.infoMessage.b, 0, 0, 0);
 
-			hud.infoMessage.surface = NULL;
+			hud.infoMessage.surface = addBorder(infoSurface, 255, 255, 255, 0, 0, 0);
+
+			addTextureToCache(hud.infoMessage.text, hud.infoMessage.surface, FALSE);
 		}
 
-		hud.infoMessage.surface = generateTextSurface(hud.infoMessage.text, game.font, hud.infoMessage.r, hud.infoMessage.g, hud.infoMessage.b, 0, 0, 0);
-
-		hud.infoMessage.surface = addBorder(hud.infoMessage.surface, 255, 255, 255, 0, 0, 0);
-
 		hud.infoMessage.thinkTime = (head->thinkTime <= 0 ? 5 : head->thinkTime);
 
 		messageHead.next = head->next;
@@ -476,8 +495,6 @@ void freeMessageQueue()
 
 	if (hud.infoMessage.surface != NULL)
 	{
-		SDL_FreeSurface(hud.infoMessage.surface);
-
 		hud.infoMessage.surface = NULL;
 
 		hud.infoMessage.text[0] = '\0';
@@ -509,6 +526,7 @@ void showMedal(int medalType, char *message)
 {
 	SDL_Surface *textSurface, *medalSurface;
 	SDL_Rect dest;
+	Texture *medalTexture, *textTexture, *targetTexture;
 
 	if (hud.medalTextSurface != NULL)
 	{
@@ -517,31 +535,39 @@ void showMedal(int medalType, char *message)
 
 	textSurface = generateTextSurface(_(message), game.font, 0, 220, 0, 0, 0, 0);
 
-	medalSurface = createSurface(textSurface->w + hud.medalSurface[medalType]->w + 18, MAX(textSurface->h, hud.medalSurface[medalType]->h));
+	textTexture = convertSurfaceToTexture(textSurface, TRUE);
+	
+	medalSurface = createSurface(textSurface->w + hud.medalSurface[medalType]->w + 18, MAX(textTexture->h, hud.medalSurface[medalType]->h), FALSE);
 
-	dest.x = 5;
-	dest.y = hud.medalSurface[medalType]->h / 2 - medalSurface->h / 2;
+	medalTexture = addBorder(medalSurface, 255, 255, 255, 0, 0, 0);
+	
+	targetTexture = createWritableTexture(medalTexture->w, medalTexture->h);
+	
+	SDL_SetRenderTarget(game.renderer, targetTexture->texture);
+
+	SDL_RenderCopy(game.renderer, medalTexture->texture, NULL, NULL);
+
+	dest.x = 5 + BORDER_PADDING;
+	dest.y = medalTexture->h / 2 - hud.medalSurface[medalType]->h / 2;
 	dest.w = hud.medalSurface[medalType]->w;
 	dest.h = hud.medalSurface[medalType]->h;
 
-	SDL_BlitSurface(hud.medalSurface[medalType], NULL, medalSurface, &dest);
+	SDL_RenderCopy(game.renderer, hud.medalSurface[medalType]->texture, NULL, &dest);
 
-	dest.x = hud.medalSurface[medalType]->w + 13;
-	dest.y = hud.medalSurface[medalType]->h / 2 - textSurface->h / 2;
-	dest.w = textSurface->w;
-	dest.h = textSurface->h;
+	dest.x = hud.medalSurface[medalType]->w + 13 + BORDER_PADDING;
+	dest.y = medalTexture->h / 2 - textTexture->h / 2;
+	dest.w = textTexture->w;
+	dest.h = textTexture->h;
 
-	SDL_BlitSurface(textSurface, NULL, medalSurface, &dest);
+	SDL_RenderCopy(game.renderer, textTexture->texture, NULL, &dest);
 
-	hud.medalTextSurface = addBorder(medalSurface, 255, 255, 255, 0, 0, 0);
+	hud.medalTextSurface = targetTexture;
 
 	hud.medalThinkTime = 180;
 
-	SDL_FreeSurface(textSurface);
-
 	playSound("sound/common/trophy");
 
-	return;
+	SDL_SetRenderTarget(game.renderer, NULL);
 }
 
 int spotlightSize()
@@ -549,7 +575,7 @@ int spotlightSize()
 	return hud.spotlight->w;
 }
 
-SDL_Surface *getMedalImage(int medalType, int obtained)
+Texture *getMedalImage(int medalType, int obtained)
 {
 	return obtained == TRUE ? hud.medalSurface[medalType] : hud.disabledMedalSurface;
 }
