@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2016 Parallel Realities
+Copyright (C) 2009-2024 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -28,5 +28,5 @@ void freeBossHealthBar(void);
 void drawSpotlight(int, int);
 void showMedal(int, char *);
 int spotlightSize(void);
-SDL_Surface *getMedalImage(int, int);
+Texture *getMedalImage(int, int);
 void setSlimeTimerValue(int);
