@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2016 Parallel Realities
+Copyright (C) 2009-2024 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -20,6 +20,8 @@ Foundation, 51 Franklin Street, Suite 500, Boston, MA 02110-1335, USA.
 #include "headers.h"
 
 #include "audio/audio.h"
+#include "graphics/texture_cache.h"
+#include "init.h"
 #include "medal.h"
 #include "system/load_save.h"
 #include "system/pak.h"
@@ -32,7 +34,11 @@ extern Game game;
 void init(char *title, int joystickNum)
 {
 	int joysticks, buttons;
-	long flags;
+	long windowFlags, rendererFlags;
+
+	windowFlags = 0;
+
+	rendererFlags = SDL_RENDERER_ACCELERATED;
 
 	/* Set up the home directory */
 
@@ -44,7 +50,7 @@ void init(char *title, int joystickNum)
 	{
 		printf("Could not initialize SDL: %s\n", SDL_GetError());
 
-		exit(1);
+		cleanup(1);
 	}
 
 	/* Initialise SDL_TTF */
@@ -53,29 +59,27 @@ void init(char *title, int joystickNum)
 	{
 		printf("Couldn't initialize SDL TTF: %s\n", SDL_GetError());
 
-		exit(1);
+		cleanup(1);
 	}
 
-	flags = SDL_HWPALETTE|SDL_DOUBLEBUF|SDL_HWSURFACE;
-
 	/* Load the settings */
 
 	loadConfig();
 
 	if (game.fullscreen == TRUE)
 	{
-		flags |= SDL_FULLSCREEN;
+		windowFlags |= SDL_WINDOW_FULLSCREEN;
 	}
 
 	/* Open a screen */
 
-	game.screen = SDL_SetVideoMode(SCREEN_WIDTH, SCREEN_HEIGHT, 0, flags);
+	game.window = SDL_CreateWindow(title, SDL_WINDOWPOS_UNDEFINED, SDL_WINDOWPOS_UNDEFINED, SCREEN_WIDTH, SCREEN_HEIGHT, windowFlags);
 
-	if (game.screen == NULL)
+	if (game.window == NULL)
 	{
 		printf("Couldn't set screen mode to %d x %d: %s\n", SCREEN_WIDTH, SCREEN_HEIGHT, SDL_GetError());
 
-		exit(1);
+		cleanup(1);
 	}
 
 	if (game.audio == TRUE)
@@ -96,7 +100,7 @@ void init(char *title, int joystickNum)
 
 	if (joysticks > 0)
 	{
-		printf("Found %d joysticks. Opening Joystick #%d: %s\n", joysticks, joystickNum, SDL_JoystickName(joystickNum));
+		printf("Found %d joysticks. Opening Joystick #%d\n", joysticks, joystickNum);
 
 		game.joystick = SDL_JoystickOpen(joystickNum);
 
@@ -107,18 +111,32 @@ void init(char *title, int joystickNum)
 		printf("Joystick has %d axes\n", SDL_JoystickNumAxes(game.joystick));
 	}
 
-	/* Set the screen title */
+	/* Set the scaling hint */
 
-	SDL_WM_SetCaption(title, NULL);
+	SDL_SetHint(SDL_HINT_RENDER_SCALE_QUALITY, "linear");
 
-	/* Hide the mouse cursor */
+	/* Init the renderers */
 
-	SDL_ShowCursor(SDL_DISABLE);
+	game.renderer = SDL_CreateRenderer(game.window, -1, rendererFlags);
+
+	/* Enable blending */
+
+	SDL_SetRenderDrawBlendMode(game.renderer, SDL_BLENDMODE_BLEND);
+
+	/* Init SDL Image */
+	IMG_Init(IMG_INIT_PNG|IMG_INIT_JPG);
+
+	/* Hide the cursor */
+
+	SDL_ShowCursor(0);
 
 	/* Set the prandom seed */
 
 	setSeed(time(NULL));
 
+	/* Initalise the texture cache */
+	initTextureCache();
+
 	/* Init the PAK file */
 
 	initPakFile();
@@ -130,14 +148,52 @@ void init(char *title, int joystickNum)
 
 void toggleFullScreen()
 {
-	long flags = game.screen->flags;
+	long fullScreen = SDL_GetWindowFlags(game.window) & SDL_WINDOW_FULLSCREEN;
 
-	flags ^= SDL_FULLSCREEN;
+	fullScreen ^= SDL_WINDOW_FULLSCREEN;
 
-	game.screen = SDL_SetVideoMode(SCREEN_WIDTH, SCREEN_HEIGHT, 0, flags);
+	SDL_SetWindowFullscreen(game.window, fullScreen);
 }
 
-void cleanup()
+void addJoystick(int joystickNum)
+{
+	int buttons = 0;
+	
+	printf("Detected joystick\n");
+
+	if (joystickNum == 0)
+	{
+		printf("Opening Joystick #%d\n", joystickNum);
+
+		game.joystick = SDL_JoystickOpen(joystickNum);
+
+		buttons = SDL_JoystickNumButtons(game.joystick);
+
+		printf("Joystick has %d buttons\n", buttons);
+
+		printf("Joystick has %d axes\n", SDL_JoystickNumAxes(game.joystick));
+	}
+}
+
+int removeJoystick(int joystickNum)
+{
+	printf("Joystick removed\n");
+
+	if (joystickNum == 0 && game.joystick != NULL)
+	{
+		printf("Closing joystick #%d\n", joystickNum);
+		
+		SDL_JoystickClose(game.joystick);
+		
+		game.joystick = NULL;
+		
+		return TRUE;
+	}
+	
+	return FALSE;
+}
+
+void cleanup(int exitCode)
 {
 	float fps;
 
@@ -198,10 +254,16 @@ void cleanup()
 
 	/* Shut down SDL */
 
+	SDL_DestroyRenderer(game.renderer);
+
+	SDL_DestroyWindow(game.window);
+
 	SDL_Quit();
+	
+	exit(exitCode);
 }
 
 void quitGame()
 {
-	exit(0);
+	cleanup(0);
 }
