@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2016 Parallel Realities
+Copyright (C) 2009-2024 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -46,16 +46,24 @@ void getInput(int gameType)
 		switch (event.type)
 		{
 			case SDL_QUIT:
-				exit(0);
+				cleanup(0);
 			break;
 
-			case SDL_ACTIVEEVENT:
-				if ((event.active.state & SDL_APPINPUTFOCUS) && event.active.gain == FALSE)
+			case SDL_WINDOWEVENT:
+				switch (event.window.event)
 				{
-					focusLost();
+					case SDL_WINDOWEVENT_FOCUS_LOST:
+						focusLost();
+					break;
 				}
-
-				else if ((event.active.state & SDL_APPACTIVE) && event.active.gain == FALSE)
+			break;
+			
+			case SDL_JOYDEVICEADDED:
+				addJoystick(event.jdevice.which);
+			break;
+			
+			case SDL_JOYDEVICEREMOVED:
+				if (removeJoystick(event.jdevice.which) == TRUE)
 				{
 					focusLost();
 				}
@@ -70,7 +78,7 @@ void getInput(int gameType)
 				{
 					if (key == SDLK_ESCAPE)
 					{
-						exit(0);
+						cleanup(0);
 					}
 				}
 
@@ -192,7 +200,7 @@ void getInput(int gameType)
 
 				else if (key == SCREENSHOT_KEY && game.gameType != RECORDING)
 				{
-					takeSingleScreenshot("edgar.bmp");
+					takeSingleScreenshot("edgar.png");
 				}
 
 				if (key == SDLK_UP)
@@ -720,7 +728,7 @@ int getSingleInput()
 		switch (event.type)
 		{
 			case SDL_QUIT:
-				exit(0);
+				cleanup(0);
 			break;
 
 			case SDL_KEYDOWN:
@@ -878,21 +886,21 @@ void readControlsFromFile(char *buffer)
 
 char *getKeyValue(int key)
 {
-	char *text;
+	static char text[MAX_VALUE_LENGTH];
 
 	if (key == -1)
 	{
-		text = "?";
+		STRNCPY(text, "?", MAX_VALUE_LENGTH);
 	}
 
 	else if (key < 0)
 	{
-		text = getJoystickButton(key);
+		STRNCPY(text, getJoystickButton(key), MAX_VALUE_LENGTH);
 	}
 
 	else
 	{
-		text = SDL_GetKeyName(key);
+		STRNCPY(text, SDL_GetKeyName(key), MAX_VALUE_LENGTH);
 	}
 
 	return text;
@@ -904,7 +912,7 @@ static char *getJoystickButton(int val)
 
 	val = abs(val) - 1000;
 
-	snprintf(text, MAX_VALUE_LENGTH, _("Joy Button #%d"), val);
+	SNPRINTF(text, MAX_VALUE_LENGTH, _("Joy Button #%d"), val);
 
 	return text;
 }
