@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2016 Parallel Realities
+Copyright (C) 2009-2024 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -76,7 +76,12 @@ static void useHealthPotion(int val)
 			setInventoryDialogMessage(_("Used %s"), _(self->objectiveName));
 		}
 
-		player.health = player.maxHealth;
+		player.health += 5;
+
+		if (player.health > player.maxHealth)
+		{
+			player.health = player.maxHealth;
+		}
 
 		self->health--;
 
