@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2016 Parallel Realities
+Copyright (C) 2009-2024 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -24,9 +24,11 @@ Foundation, 51 Franklin Street, Suite 500, Boston, MA 02110-1335, USA.
 #include "dialog.h"
 #include "draw.h"
 #include "entity.h"
+#include "event/script.h"
 #include "game.h"
 #include "graphics/decoration.h"
 #include "graphics/graphics.h"
+#include "graphics/texture_cache.h"
 #include "hud.h"
 #include "init.h"
 #include "input.h"
@@ -78,7 +80,7 @@ int main(int argc, char *argv[])
 				printf("You must specify a file to record to\n");
 				printf("Type %s -h for help\n", argv[0]);
 
-				exit(1);
+				cleanup(1);
 			}
 
 			if (recordingID == -1)
@@ -96,7 +98,7 @@ int main(int argc, char *argv[])
 				printf("You must specify a file to playback from\n");
 				printf("Type %s -h for help\n", argv[0]);
 
-				exit(1);
+				cleanup(1);
 			}
 
 			if (replayingID == -1)
@@ -114,7 +116,7 @@ int main(int argc, char *argv[])
 				printf("You must specify a slot to load from\n");
 				printf("Type %s -h for help\n", argv[0]);
 
-				exit(1);
+				cleanup(1);
 			}
 
 			loadSlot = atoi(argv[i + 1]);
@@ -134,7 +136,7 @@ int main(int argc, char *argv[])
 				printf("You must specify a joystick slot to use\n");
 				printf("Type %s -h for help\n", argv[0]);
 
-				exit(1);
+				cleanup(1);
 			}
 
 			joystick = atoi(argv[i + 1]);
@@ -154,7 +156,7 @@ int main(int argc, char *argv[])
 				printf("You must specify a language to use\n");
 				printf("Type %s -h for help\n", argv[0]);
 
-				exit(1);
+				cleanup(1);
 			}
 
 			languageID = i + 1;
@@ -173,7 +175,7 @@ int main(int argc, char *argv[])
 			printf("\t-showcredits: Shows the end credits\n");
 			printf("\t-language <language_code>: Use language <language_code>. e.g. en_US, es, pl\n\n");
 
-			exit(0);
+			cleanup(0);
 		}
 
 		#if DEV == 1
@@ -200,10 +202,6 @@ int main(int argc, char *argv[])
 	printf("Numeric is %s\n", setlocale(LC_NUMERIC, "C"));
 	printf("atof(2.75) is %f\n", atof("2.75"));
 
-	/* Call the cleanup function when the program exits */
-
-	atexit(cleanup);
-
 	/* Start up SDL */
 
 	init(_("The Legend of Edgar"), joystick);
@@ -380,5 +378,5 @@ int main(int argc, char *argv[])
 
 	/* Exit the program */
 
-	exit(0);
+	cleanup(0);
 }
