@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2016 Parallel Realities
+Copyright (C) 2009-2024 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -46,7 +46,7 @@ int main(int argc, char *argv[])
 	#if DEV == 0
 		printf("Editor doesn't work if DEV is set to 0\n");
 
-		exit(1);
+		cleanup(1);
 	#endif
 
 	setLanguage("edgar", NULL);
@@ -55,10 +55,6 @@ int main(int argc, char *argv[])
 
 	init("Map Editor", 1);
 
-	/* Call the cleanup function when the program exits */
-
-	atexit(cleanup);
-
 	export = FALSE;
 
 	go = TRUE;
@@ -87,7 +83,7 @@ int main(int argc, char *argv[])
 	{
 		printf("Usage: %s <map file name>\n", argv[0]);
 
-		exit(1);
+		cleanup(1);
 	}
 
 	if (export == TRUE)
@@ -168,7 +164,7 @@ int main(int argc, char *argv[])
 
 			drawExport();
 
-			snprintf(filename, MAX_VALUE_LENGTH, "%03d_%s_%03d.bmp", row, argv[1], col);
+			SNPRINTF(filename, MAX_VALUE_LENGTH, "%03d_%s_%03d.png", row, argv[1], col);
 
 			takeSingleScreenshot(filename);
 
@@ -188,7 +184,7 @@ int main(int argc, char *argv[])
 
 				if (y >= maxY)
 				{
-					exit(0);
+					cleanup(0);
 				}
 			}
 
@@ -227,5 +223,5 @@ int main(int argc, char *argv[])
 
 	/* Exit the program */
 
-	exit(0);
+	cleanup(0);
 }
