@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2016 Parallel Realities
+Copyright (C) 2009-2024 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -37,7 +37,7 @@ Foundation, 51 Franklin Street, Suite 500, Boston, MA 02110-1335, USA.
 #include "world/target.h"
 
 static Map map;
-static SDL_Surface *mapImages[MAX_TILES];
+static Texture *mapImages[MAX_TILES];
 static int lavaTile, waterTile, slimeTile;
 
 extern Entity *self, player;
@@ -64,7 +64,7 @@ void loadMap(char *name, int loadEntityResources)
 
 	waterTile = WATER_TILE_START + 1;
 
-	snprintf(filename, sizeof(filename), "data/maps/%s.dat", name);
+	SNPRINTF(filename, sizeof(filename), "data/maps/%s.dat", name);
 
 	buffer = loadFileFromPak(filename);
 
@@ -506,7 +506,7 @@ int saveMap()
 		return FALSE;
 	}
 
-	snprintf(filename, sizeof(filename), "data/maps/%s.dat", map.filename);
+	SNPRINTF(filename, sizeof(filename), "data/maps/%s.dat", map.filename);
 
 	printf("Saving map to %s\n", filename);
 
@@ -652,7 +652,7 @@ static void loadMapTiles(char *dir)
 
 	for (i=1;i<MAX_TILES;i++)
 	{
-		snprintf(filename, sizeof(filename), "gfx/map/%s/%d.png", dir, i);
+		SNPRINTF(filename, sizeof(filename), "gfx/map/%s/%d.png", dir, i);
 
 		if (existsInPak(filename) == FALSE)
 		{
@@ -662,11 +662,11 @@ static void loadMapTiles(char *dir)
 		mapImages[i] = loadImage(filename);
 	}
 
-	snprintf(filename, sizeof(filename), "gfx/map/%s/background.png", dir);
+	SNPRINTF(filename, sizeof(filename), "gfx/map/%s/background.png", dir);
 
 	loadMapBackground(filename, 0);
 
-	snprintf(filename, sizeof(filename), "gfx/map/%s/background1.png", dir);
+	SNPRINTF(filename, sizeof(filename), "gfx/map/%s/background1.png", dir);
 
 	loadMapBackground(filename, 1);
 }
@@ -840,13 +840,13 @@ void drawMap(int depth)
 			{
 				printf("Tile %d is NULL\n", tileID);
 
-				exit(0);
+				cleanup(0);
 			}
 			*/
 
 			if (game.status == IN_CREDITS)
 			{
-				drawBox(game.screen, x, y, TILE_SIZE, TILE_SIZE, 0, 0, 0);
+				drawBox(x, y, TILE_SIZE, TILE_SIZE, 0, 0, 0, 255);
 			}
 
 			else
@@ -987,7 +987,7 @@ void centerEntityOnMap()
 		}
 	}
 
-	if (abs(map.cameraX - map.startX) > speed)
+	if (fabsf(map.cameraX - map.startX) > speed)
 	{
 		map.cameraX += map.cameraX < map.startX ? speed : -speed;
 	}
@@ -997,7 +997,7 @@ void centerEntityOnMap()
 		map.cameraX = map.startX;
 	}
 
-	if (abs(map.cameraY - map.startY) > speed)
+	if (fabsf(map.cameraY - map.startY) > speed)
 	{
 		if (map.cameraY < map.startY)
 		{
@@ -1055,7 +1055,7 @@ static void loadAmbience(char *dir)
 	{
 		for (j=0;extensions[j]!=NULL;j++)
 		{
-			snprintf(filename, sizeof(filename), "ambience/%s/%d.%s", dir, i, extensions[j]);
+			SNPRINTF(filename, sizeof(filename), "ambience/%s/%d.%s", dir, i, extensions[j]);
 
 			if (existsInPak(filename) == FALSE)
 			{
@@ -1077,14 +1077,14 @@ void freeMap()
 
 	if (map.background[0] != NULL)
 	{
-		SDL_FreeSurface(map.background[0]);
+		destroyTexture(map.background[0]);
 
 		map.background[0] = NULL;
 	}
 
 	if (map.background[1] != NULL)
 	{
-		SDL_FreeSurface(map.background[1]);
+		destroyTexture(map.background[1]);
 
 		map.background[1] = NULL;
 	}
@@ -1095,7 +1095,7 @@ void freeMap()
 	{
 		if (mapImages[i] != NULL)
 		{
-			SDL_FreeSurface(mapImages[i]);
+			destroyTexture(mapImages[i]);
 
 			mapImages[i] = NULL;
 		}
@@ -1116,12 +1116,12 @@ void freeMap()
 	memset(&map, 0, sizeof(Map));
 }
 
-SDL_Surface *tileImage(int id)
+Texture *tileImage(int id)
 {
 	return mapImages[id];
 }
 
-SDL_Surface *mapImageAt(int x, int y)
+Texture *mapImageAt(int x, int y)
 {
 	return mapImages[map.tile[y][x]];
 }
