@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2016 Parallel Realities
+Copyright (C) 2009-2024 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -23,8 +23,8 @@ void doMap(void);
 void drawMap(int);
 void centerEntityOnMap(void);
 void freeMap(void);
-SDL_Surface *tileImage(int);
-SDL_Surface *mapImageAt(int, int);
+Texture *tileImage(int);
+Texture *mapImageAt(int, int);
 int mapTileAt(int, int);
 int getMapMaxX(void);
 int getMapMaxY(void);
