@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2016 Parallel Realities
+Copyright (C) 2009-2024 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -416,7 +416,7 @@ static void realignGrid()
 	{
 		if (menu.background != NULL)
 		{
-			SDL_FreeSurface(menu.background);
+			destroyTexture(menu.background);
 
 			menu.background = NULL;
 		}
@@ -424,7 +424,7 @@ static void realignGrid()
 		menu.w = w;
 		menu.h = y - BORDER_PADDING;
 
-		menu.background = addBorder(createSurface(menu.w, menu.h), 255, 255, 255, 0, 0, 0);
+		menu.background = addBorder(createSurface(menu.w, menu.h, FALSE), 255, 255, 255, 0, 0, 0);
 
 		menu.x = (SCREEN_WIDTH - menu.background->w) / 2;
 		menu.y = (SCREEN_HEIGHT - menu.background->h) / 2;
@@ -449,7 +449,7 @@ void freeControlMenu()
 
 	if (menu.background != NULL)
 	{
-		SDL_FreeSurface(menu.background);
+		destroyTexture(menu.background);
 
 		menu.background = NULL;
 	}
@@ -613,7 +613,7 @@ static char *getDeadZoneValue(int value)
 		showErrorAndExit("Failed to allocate a whole 10 bytes for the dead zone label");
 	}
 
-	snprintf(text, 10, "%d", value);
+	SNPRINTF(text, 10, "%d", value);
 
 	return text;
 }
