@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2016 Parallel Realities
+Copyright (C) 2009-2024 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -284,7 +284,7 @@ static void loadMenuLayout()
 	menu.w = w + BUTTON_PADDING;
 	menu.h = y - BORDER_PADDING;
 
-	menu.background = addBorder(createSurface(menu.w, menu.h), 255, 255, 255, 0, 0, 0);
+	menu.background = addBorder(createSurface(menu.w, menu.h, FALSE), 255, 255, 255, 0, 0, 0);
 
 	menu.x = (SCREEN_WIDTH - menu.background->w) / 2;
 	menu.y = (SCREEN_HEIGHT - menu.background->h) / 2;
@@ -322,7 +322,7 @@ void freeSoundMenu()
 
 	if (menu.background != NULL)
 	{
-		SDL_FreeSurface(menu.background);
+		destroyTexture(menu.background);
 
 		menu.background = NULL;
 	}
@@ -441,7 +441,7 @@ static char *getVolumePercent(int volume)
 		showErrorAndExit("Failed to allocate a whole 3 bytes for a Volume label");
 	}
 
-	snprintf(text, 3, "%d", volume);
+	SNPRINTF(text, 3, "%d", volume);
 
 	return text;
 }
@@ -462,7 +462,7 @@ static char *getQuality()
 		showErrorAndExit("Failed to allocate a whole 10 bytes for a Quality label");
 	}
 
-	snprintf(text, 10, "%d", game.audioQuality);
+	SNPRINTF(text, 10, "%d", game.audioQuality);
 
 	return text;
 }
