@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2016 Parallel Realities
+Copyright (C) 2009-2024 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -115,21 +115,21 @@ void freeWidget(Widget *w)
 	{
 		if (w->normalState != NULL)
 		{
-			SDL_FreeSurface(w->normalState);
+			destroyTexture(w->normalState);
 
 			w->normalState = NULL;
 		}
 
 		if (w->selectedState != NULL)
 		{
-			SDL_FreeSurface(w->selectedState);
+			destroyTexture(w->selectedState);
 
 			w->selectedState = NULL;
 		}
 
 		if (w->disabledState != NULL)
 		{
-			SDL_FreeSurface(w->disabledState);
+			destroyTexture(w->disabledState);
 
 			w->disabledState = NULL;
 		}
@@ -178,11 +178,11 @@ static SDL_Surface *createWidgetText(char *msg, TTF_Font *font, int fr, int fg,
 
 	lines = i;
 
-	surface = malloc(sizeof(SDL_Surface *) * lines);
+	surface = malloc(sizeof(SDL_Texture *) * lines);
 
 	if (surface == NULL)
 	{
-		showErrorAndExit("Failed to allocate a whole %d bytes for the Dialog Surfaces", (int)sizeof(SDL_Surface *) * lines);
+		showErrorAndExit("Failed to allocate a whole %d bytes for the Dialog Surfaces", (int)sizeof(SDL_Texture *) * lines);
 	}
 
 	lineBreaks = malloc(sizeof(int) * lines);
@@ -204,7 +204,7 @@ static SDL_Surface *createWidgetText(char *msg, TTF_Font *font, int fr, int fg,
 	{
 		lineBreak = FALSE;
 
-		snprintf(word, sizeof(word), "%s ", token);
+		SNPRINTF(word, sizeof(word), "%s ", token);
 
 		if (word[strlen(word) - 2] == '\n')
 		{
@@ -255,7 +255,7 @@ static SDL_Surface *createWidgetText(char *msg, TTF_Font *font, int fr, int fg,
 
 	h -= 5;
 
-	tempSurface = createSurface(maxWidth, h);
+	tempSurface = createSurface(maxWidth, h, FALSE);
 
 	w = h = 0;
 
