@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2016 Parallel Realities
+Copyright (C) 2009-2024 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -20,19 +20,20 @@ Foundation, 51 Franklin Street, Suite 500, Boston, MA 02110-1335, USA.
 #include "headers.h"
 
 FILE *pak;
-int fileID = 0;
+int fileID;
 int32_t totalFiles;
 FileData *fileData;
+char **filenames;
 
-static int countFiles(char *);
-static void cleanup(void);
-static void recurseDirectory(char *);
-static void compressFile(char *, DIR *);
+static void getFilenames(char *, int *);
+static void cleanup(int);
+static void compressFile(char *);
 static void testPak(char *);
+static int compare (const void *, const void *);
 
 int main(int argc, char *argv[])
 {
-	int i;
+	int i, arraySize;
 	int32_t length;
 	char versionName[5];
 	FILE *versionFile;
@@ -43,7 +44,7 @@ int main(int argc, char *argv[])
 		{
 			testPak(argv[2]);
 
-			exit(0);
+			cleanup(0);
 		}
 	}
 
@@ -52,17 +53,21 @@ int main(int argc, char *argv[])
 		printf("Usage   : pak <directory names> <outputname>\n");
 		printf("Example : pak data music gfx sound font edgar.pak\n");
 
-		exit(1);
+		cleanup(1);
 	}
 
 	pak = fopen(argv[argc - 1], "wb");
 
-	totalFiles = 0;
+	arraySize = 1000;
+	
+	filenames = malloc(arraySize * sizeof(char *));
 
 	for (i=1;i<argc-1;i++)
 	{
-		totalFiles += countFiles(argv[i]);
+		getFilenames(argv[i], &arraySize);
 	}
+	
+	qsort(filenames, totalFiles, sizeof(char *), compare);
 
 	totalFiles++;
 
@@ -76,12 +81,10 @@ int main(int argc, char *argv[])
 	{
 		printf("Failed to create File Data\n");
 
-		exit(1);
+		cleanup(1);
 	}
 
-	atexit(cleanup);
-
-	snprintf(versionName, sizeof(versionName), "%0.2f", VERSION);
+	SNPRINTF(versionName, sizeof(versionName), "%0.2f", VERSION);
 
 	versionFile = fopen(versionName, "wb");
 
@@ -89,12 +92,12 @@ int main(int argc, char *argv[])
 
 	fclose(versionFile);
 
-	for (i=1;i<argc-1;i++)
+	for (i=0;i<totalFiles-1;i++)
 	{
-		recurseDirectory(argv[i]);
+		compressFile(filenames[i]);
 	}
 
-	compressFile(versionName, NULL);
+	compressFile(versionName);
 
 	remove(versionName);
 
@@ -127,12 +130,12 @@ int main(int argc, char *argv[])
 	return 0;
 }
 
-static int countFiles(char *dirName)
+static void getFilenames(char *dirName, int *arraySize)
 {
 	DIR *dirp, *dirp2;
 	struct dirent *dfile;
 	char filename[MAX_FILE_LENGTH];
-	int count = 0;
+	char **ptr;
 
 	dirp = opendir(dirName);
 
@@ -143,7 +146,7 @@ static int countFiles(char *dirName)
 			continue;
 		}
 
-		sprintf(filename, "%s/%s", dirName, dfile->d_name);
+		SNPRINTF(filename, sizeof(filename), "%s/%s", dirName, dfile->d_name);
 
 		dirp2 = opendir(filename);
 
@@ -151,68 +154,75 @@ static int countFiles(char *dirName)
 		{
 			closedir(dirp2);
 
-			count += countFiles(filename);
+			getFilenames(filename, arraySize);
 		}
 
 		else
 		{
-			count++;
-		}
-	}
+			filenames[totalFiles] = malloc(MAX_FILE_LENGTH);
+			
+			STRNCPY(filenames[totalFiles], filename, MAX_FILE_LENGTH);
+			
+			totalFiles++;
+			
+			if (totalFiles == *arraySize)
+			{
+				*arraySize += 500;
+				
+				ptr = realloc(filenames, *arraySize * sizeof(char *));
+				
+				if (ptr)
+				{
+					filenames = ptr;
+				}
+				
+				else
+				{
+					printf("Failed to allocate %d bytes whilst indexing files\n", *arraySize * (int)sizeof(char *));
 
-	closedir(dirp);
-
-	return count;
-}
-
-static void cleanup()
-{
-
-}
-
-static void recurseDirectory(char *dirName)
-{
-	DIR *dirp, *dirp2;
-	struct dirent *dfile;
-	char filename[1024];
-
-	dirp = opendir(dirName);
-
-	if (dirp == NULL)
-	{
-		printf("%s: Directory does not exist or is not accessable\n", dirName);
-
-		exit(1);
-	}
-
-	while ((dfile = readdir(dirp)))
-	{
-		if (dfile->d_name[0] == '.')
-		{
-			continue;
-		}
-
-		snprintf(filename, sizeof(filename), "%s/%s", dirName, dfile->d_name);
-
-		dirp2 = opendir(filename);
-
-		if (dirp2)
-		{
-			closedir(dirp2);
-
-			recurseDirectory(filename);
-		}
-
-		else
-		{
-			compressFile(filename, dirp);
+					cleanup(1);
+				}
+			}
 		}
 	}
 
 	closedir(dirp);
 }
 
-static void compressFile(char *filename, DIR *dirp)
+static int compare(const void *a, const void *b)
+{
+	char* aa = *(char**)a;
+	char* bb = *(char**)b;
+	
+	return strcmpignorecase(aa, bb);
+}
+
+static void cleanup(int exitCode)
+{
+	int i;
+	
+	if (filenames != NULL)
+	{
+		for (i=0;i<totalFiles-1;i++)
+		{
+			if (filenames[i] != NULL)
+			{
+				free(filenames[i]);
+			}
+		}
+		
+		free(filenames);
+	}
+	
+	if (fileData != NULL)
+	{
+		free(fileData);
+	}
+	
+	exit(exitCode);
+}
+
+static void compressFile(char *filename)
 {
 	FILE *infile;
 	int compressionResult;
@@ -228,10 +238,7 @@ static void compressFile(char *filename, DIR *dirp)
 	{
 		printf("Couldn't open %s for reading!\n", filename);
 
-		closedir(dirp);
-		fclose(pak);
-
-		exit(1);
+		cleanup(1);
 	}
 
 	fseek(infile, 0L, SEEK_END);
@@ -242,7 +249,7 @@ static void compressFile(char *filename, DIR *dirp)
 	{
 		printf("%s is an empty file.\n", filename);
 
-		exit(1);
+		cleanup(1);
 	}
 
 	ensuredSize = fileSize * 1.01 + 12;
@@ -257,7 +264,7 @@ static void compressFile(char *filename, DIR *dirp)
 	{
 		printf("Could not create buffer\n");
 
-		exit(1);
+		cleanup(1);
 	}
 
 	output = malloc(ensuredSize * sizeof(unsigned char));
@@ -266,7 +273,7 @@ static void compressFile(char *filename, DIR *dirp)
 	{
 		printf("Could not create output\n");
 
-		exit(1);
+		cleanup(1);
 	}
 
 	fp = gzopen(filename, "rb");
@@ -275,11 +282,7 @@ static void compressFile(char *filename, DIR *dirp)
 	{
 		printf("Couldn't open %s for reading!\n", filename);
 
-		closedir(dirp);
-
-		fclose(pak);
-
-		exit(1);
+		cleanup(1);
 	}
 
 	gzread(fp, buffer, fileSize);
@@ -312,7 +315,7 @@ static void compressFile(char *filename, DIR *dirp)
 			printf("Unknown error\n");
 		}
 
-		exit(1);
+		cleanup(1);
 	}
 
 	percentage = fileID;
@@ -353,10 +356,12 @@ static void testPak(char *pakFile)
 	{
 		printf("Failed to open PAK file %s\n", pakFile);
 
-		exit(1);
+		cleanup(1);
 	}
 
-	fseek(fp, -(sizeof(int32_t) + sizeof(int32_t)), SEEK_END);
+	offset = sizeof(int32_t) + sizeof(int32_t);
+
+	fseek(fp, -offset, SEEK_END);
 
 	fread(&offset, sizeof(int32_t), 1, fp);
 	fread(&fileCount, sizeof(int32_t), 1, fp);
@@ -368,9 +373,9 @@ static void testPak(char *pakFile)
 
 	if (fileData == NULL)
 	{
-		printf("Could not allocate %d bytes for FileData\n", (int)(fileCount * sizeof(FileData)));
+		printf("Could not allocate %d bytes for FileData\n", fileCount * (int)sizeof(FileData));
 
-		exit(1);
+		cleanup(1);
 	}
 
 	fseek(fp, offset, SEEK_SET);
@@ -400,7 +405,7 @@ static void testPak(char *pakFile)
 		{
 			printf("\nFailed to allocate %d bytes to load %s from PAK\n", fileData[i].compressedSize * (int)sizeof(unsigned char), fileData[i].filename);
 
-			exit(1);
+			cleanup(1);
 		}
 
 		dest = malloc((fileData[i].fileSize + 1) * sizeof(unsigned char));
@@ -409,7 +414,7 @@ static void testPak(char *pakFile)
 		{
 			printf("\nFailed to allocate %d bytes to load %s from PAK\n", fileData[i].fileSize * (int)sizeof(unsigned char), fileData[i].filename);
 
-			exit(1);
+			cleanup(1);
 		}
 
 		fread(source, fileData[i].compressedSize, 1, fp);
@@ -424,7 +429,7 @@ static void testPak(char *pakFile)
 		{
 			printf("\nFailed to decompress %s. Expected %d, got %ld\n", fileData[i].filename, fileData[i].fileSize, size);
 
-			exit(1);
+			cleanup(1);
 		}
 
 		free(source);
