@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2016 Parallel Realities
+Copyright (C) 2009-2024 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -604,7 +604,7 @@ void doPlayer()
 
 					else
 					{
-						if (playerShield.inUse == TRUE && playerShield.health >= 4)
+						if (playerShield.inUse == TRUE && playerShield.health >= 4 && strcmpignorecase(playerShield.objectiveName, "Disintegration Shield") == 0)
 						{
 							setEntityAnimation(self, "STAND");
 							setEntityAnimation(&playerShield, "STAND");
@@ -1351,7 +1351,7 @@ static void takeDamage(Entity *other, int damage)
 
 						STRNCPY(oldShieldName, playerShield.name, sizeof(oldShieldName));
 
-						snprintf(shieldName, MAX_VALUE_LENGTH, "weapon/disintegration_shield_%d", shieldHealth);
+						SNPRINTF(shieldName, MAX_VALUE_LENGTH, "weapon/disintegration_shield_%d", shieldHealth);
 
 						loadProperties(shieldName, &playerShield);
 
@@ -2427,6 +2427,8 @@ static void shieldTouch(Entity *other)
 		playSoundToMap("sound/edgar/shield", BOSS_CHANNEL, player.x, player.y, 0);
 
 		other->health = 0;
+
+		fadeFromColour(255, 0, 0, 15);
 	}
 }
 
