@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2016 Parallel Realities
+Copyright (C) 2009-2024 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -21,32 +21,34 @@ Foundation, 51 Franklin Street, Suite 500, Boston, MA 02110-1335, USA.
 
 #include "graphics/font.h"
 #include "graphics/graphics.h"
+#include "graphics/texture_cache.h"
 
 extern Game game;
 
-static SDL_Surface *panel;
+static Texture *panel;
 
 void setStatusPanelMessage(char *fmt, ...)
 {
 	char text[MAX_MESSAGE_LENGTH];
+	SDL_Surface *surface;
 	va_list ap;
 
 	va_start(ap, fmt);
 	vsnprintf(text, sizeof(text), fmt, ap);
 	va_end(ap);
 
-	if (panel != NULL)
-	{
-		SDL_FreeSurface(panel);
-
-		panel = NULL;
-	}
-
 	if (strlen(text) > 0)
 	{
-		panel = generateTextSurface(text, game.font, 255, 255, 255, 0, 0, 0);
+		panel = getTextureFromCache(text);
 
-		panel = addBorder(panel, 255, 255, 255, 0, 0, 0);
+		if (panel == NULL)
+		{
+			surface = generateTextSurface(text, game.font, 255, 255, 255, 0, 0, 0);
+
+			panel = addBorder(surface, 255, 255, 255, 0, 0, 0);
+
+			addTextureToCache(text, panel, FALSE);
+		}
 	}
 }
 
@@ -57,13 +59,3 @@ void drawStatusPanel()
 		drawImage(panel, (SCREEN_WIDTH - panel->w) / 2, SCREEN_HEIGHT - TILE_SIZE - 1, FALSE, 255);
 	}
 }
-
-void freeStatusPanel()
-{
-	if (panel != NULL)
-	{
-		SDL_FreeSurface(panel);
-
-		panel = NULL;
-	}
-}
