@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2016 Parallel Realities
+Copyright (C) 2009-2024 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -19,6 +19,10 @@ Foundation, 51 Franklin Street, Suite 500, Boston, MA 02110-1335, USA.
 
 #include "../headers.h"
 
+#ifdef __HAIKU__
+#include <FindDirectory.h>
+#endif
+
 #include "../audio/music.h"
 #include "../entity.h"
 #include "../event/global_trigger.h"
@@ -30,6 +34,7 @@ Foundation, 51 Franklin Street, Suite 500, Boston, MA 02110-1335, USA.
 #include "../graphics/font.h"
 #include "../graphics/graphics.h"
 #include "../hud.h"
+#include "../init.h"
 #include "../input.h"
 #include "../inventory.h"
 #include "../map.h"
@@ -57,6 +62,9 @@ extern Game game;
 	{
 		char *userHome;
 		char dir[MAX_PATH_LENGTH];
+		#ifdef __HAIKU__
+		char path[MAX_PATH_LENGTH];
+		#endif
 		struct passwd *pass;
 
 		pass = getpwuid(geteuid());
@@ -65,56 +73,104 @@ extern Game game;
 		{
 			printf("Couldn't determine the user home directory. Exiting.\n");
 
-			exit(1);
+			cleanup(1);
 		}
 
 		userHome = pass->pw_dir;
 
 		#if MACOS == 1
-		snprintf(dir, sizeof(dir), "%s/Library/Application Support", userHome);
+		SNPRINTF(dir, sizeof(dir), "%s/Library/Application Support", userHome);
+		#elif defined(__HAIKU__)
+		find_directory(B_USER_SETTINGS_DIRECTORY, 0, true, path, sizeof(path));
+		SNPRINTF(dir, sizeof(dir), "%s/parallelrealities", path);
 		#else
-		snprintf(dir, sizeof(dir), "%s/.parallelrealities", userHome);
+		SNPRINTF(dir, sizeof(dir), "%s/.parallelrealities", userHome);
 		#endif
 
-		if ((mkdir(dir, S_IRWXU|S_IRWXG|S_IROTH|S_IXOTH) != 0) && (errno != EEXIST))
+		if (mkdir(dir, S_IRWXU|S_IRWXG|S_IROTH|S_IXOTH) != 0 && errno != EEXIST)
 		{
-			printf("Couldn't create required directory '%s'", dir);
+			printf("Couldn't create required directory '%s'\n", dir);
 
-			exit(1);
+			cleanup(1);
 		}
 
 		#if MACOS == 1
-		snprintf(dir, sizeof(dir), "%s/Library/Application Support/Edgar", userHome);
+		SNPRINTF(dir, sizeof(dir), "%s/Library/Application Support/Edgar", userHome);
+		#elif defined(__HAIKU__)
+		find_directory(B_USER_SETTINGS_DIRECTORY, 0, true, path, sizeof(path));
+		SNPRINTF(dir, sizeof(dir), "%s/parallelrealities/Edgar", path);
 		#else
-		snprintf(dir, sizeof(dir), "%s/.parallelrealities/edgar", userHome);
+		SNPRINTF(dir, sizeof(dir), "%s/.parallelrealities/edgar", userHome);
 		#endif
 
-		if ((mkdir(dir, S_IRWXU|S_IRWXG|S_IROTH|S_IXOTH) != 0) && (errno != EEXIST))
+		if (mkdir(dir, S_IRWXU|S_IRWXG|S_IROTH|S_IXOTH) != 0 && errno != EEXIST)
 		{
-			printf("Couldn't create required directory '%s'", dir);
+			printf("Couldn't create required directory '%s'\n", dir);
 
-			exit(1);
+			cleanup(1);
 		}
 
 		#if MACOS == 1
-		snprintf(gameSavePath, sizeof(gameSavePath), "%s/Library/Application Support/Edgar/", userHome);
+		SNPRINTF(gameSavePath, sizeof(gameSavePath), "%s/Library/Application Support/Edgar/", userHome);
+		#elif defined(__HAIKU__)
+		find_directory(B_USER_SETTINGS_DIRECTORY, 0, true, path, sizeof(path));
+		SNPRINTF(gameSavePath, sizeof(gameSavePath), "%s/parallelrealities/Edgar", path);
 		#else
-		snprintf(gameSavePath, sizeof(gameSavePath), "%s/.parallelrealities/edgar/", userHome);
+		SNPRINTF(gameSavePath, sizeof(gameSavePath), "%s/.parallelrealities/edgar/", userHome);
 		#endif
 
-		snprintf(tempFile, sizeof(tempFile), "%stmpsave", gameSavePath);
+		SNPRINTF(tempFile, sizeof(tempFile), "%stmpsave", gameSavePath);
 
-		snprintf(saveFileIndex, sizeof(saveFileIndex), "%ssaveheader", gameSavePath);
+		SNPRINTF(saveFileIndex, sizeof(saveFileIndex), "%ssaveheader", gameSavePath);
 
-		snprintf(continueFile, sizeof(continueFile), "%scontinuesave", gameSavePath);
+		SNPRINTF(continueFile, sizeof(continueFile), "%scontinuesave", gameSavePath);
+	}
+#elif _WIN32
+	void setupUserHomeDirectory()
+	{
+        char *userHome;
+        char dir[MAX_PATH_LENGTH];
+        
+        userHome = getenv("appdata");
+        
+        if (userHome == NULL)
+        {
+            userHome = "";
+        }
+        
+        SNPRINTF(dir, sizeof(dir), "%s/parallelrealities", userHome);
+        
+        if (mkdir(dir) != 0 && errno != EEXIST)
+        {
+            printf("Couldn't create required directory '%s'\n", dir);
+
+            cleanup(1);
+        }
+        
+        SNPRINTF(dir, sizeof(dir), "%s/parallelrealities/edgar", userHome);
+        
+        if (mkdir(dir) != 0 && errno != EEXIST)
+        {
+            printf("Couldn't create required directory '%s'\n", dir);
+
+            cleanup(1);
+        }
+        
+        SNPRINTF(gameSavePath, sizeof(gameSavePath), "%s/parallelrealities/edgar/", userHome);
+        
+		SNPRINTF(tempFile, sizeof(tempFile), "%stmpsave", gameSavePath);
+
+		SNPRINTF(saveFileIndex, sizeof(saveFileIndex), "%ssaveheader", gameSavePath);
+
+		SNPRINTF(continueFile, sizeof(continueFile), "%scontinuesave", gameSavePath);
 	}
 #else
 	void setupUserHomeDirectory()
 	{
-		STRNCPY(gameSavePath, "", sizeof(gameSavePath));
-		STRNCPY(tempFile, "tmpsave", sizeof(tempFile));
-		STRNCPY(saveFileIndex, "saveheader", sizeof(saveFileIndex));
-		STRNCPY(continueFile, "continuesave", sizeof(continueFile));
+        STRNCPY(gameSavePath, "", sizeof(gameSavePath));
+        STRNCPY(tempFile, "tmpsave", sizeof(tempFile));
+        STRNCPY(saveFileIndex, "saveheader", sizeof(saveFileIndex));
+        STRNCPY(continueFile, "continuesave", sizeof(continueFile));
 	}
 #endif
 
@@ -184,7 +240,7 @@ int loadGame(int slot)
 
 	savePtr = NULL;
 
-	snprintf(saveFile, sizeof(saveFile), "%ssave%d", gameSavePath, slot);
+	SNPRINTF(saveFile, sizeof(saveFile), "%ssave%d", gameSavePath, slot);
 
 	fp = fopen(saveFile, "rb");
 
@@ -299,7 +355,7 @@ int loadGame(int slot)
 
 			loadMap(itemName, FALSE);
 
-			snprintf(mapName, sizeof(mapName), "MAP_NAME %s", itemName);
+			SNPRINTF(mapName, sizeof(mapName), "MAP_NAME %s", itemName);
 		}
 
 		else if (strcmpignorecase(line, mapName) == 0)
@@ -326,7 +382,7 @@ int loadGame(int slot)
 
 		/* Back up the original save file */
 
-		snprintf(backup, sizeof(backup), "%s.bak", saveFile);
+		SNPRINTF(backup, sizeof(backup), "%s.bak", saveFile);
 
 		copyFile(saveFile, backup);
 
@@ -342,7 +398,7 @@ int loadGame(int slot)
 
 			percentage += steps;
 
-			snprintf(completion, 5, "%d%%", (int)percentage);
+			SNPRINTF(completion, 5, "%d%%", (int)percentage);
 
 			if ((int)(version * 100) > (int)(VERSION * 100))
 			{
@@ -466,7 +522,7 @@ static void patchSaveGame(char *saveFile, double version)
 
 				if (saveMap == FALSE)
 				{
-					snprintf(itemName, sizeof(itemName), "%ld_old", game.playTime * SDL_GetTicks());
+					SNPRINTF(itemName, sizeof(itemName), "%ld_old", game.playTime * SDL_GetTicks());
 				}
 
 				if (savedLocation == FALSE)
@@ -584,7 +640,7 @@ void saveGame(int slot)
 	{
 		for (i=1001;;i++)
 		{
-			snprintf(saveFile, sizeof(saveFile), "%ssave%d", gameSavePath, i);
+			SNPRINTF(saveFile, sizeof(saveFile), "%ssave%d", gameSavePath, i);
 
 			read = fopen(saveFile, "rb");
 
@@ -604,9 +660,9 @@ void saveGame(int slot)
 	{
 		/* Backup older save */
 
-		snprintf(saveFile, sizeof(saveFile), "%ssave%d", gameSavePath, slot);
+		SNPRINTF(saveFile, sizeof(saveFile), "%ssave%d", gameSavePath, slot);
 
-		snprintf(tempSaveFile, sizeof(tempSaveFile), "%stempsave%d", gameSavePath, slot);
+		SNPRINTF(tempSaveFile, sizeof(tempSaveFile), "%stempsave%d", gameSavePath, slot);
 	}
 
 	write = fopen(tempSaveFile, "wb");
@@ -797,7 +853,7 @@ static void updateSaveFileIndex(int slot)
 
 	strftime(buffer, MAX_VALUE_LENGTH, "%H:%M %d %b %Y", timeinfo);
 
-	snprintf(saveName, MAX_VALUE_LENGTH, "%s - %s", _(getMapName()), buffer);
+	SNPRINTF(saveName, MAX_VALUE_LENGTH, "%s - %s", _(getMapName()), buffer);
 
 	STRNCPY(data[slot], saveName, MAX_VALUE_LENGTH);
 
@@ -831,7 +887,7 @@ int getMostRecentSave()
 
 	for (i=0;i<MAX_SAVE_SLOTS;i++)
 	{
-		snprintf(saveFile, sizeof(saveFile), "%ssave%d", gameSavePath, i);
+		SNPRINTF(saveFile, sizeof(saveFile), "%ssave%d", gameSavePath, i);
 
 		fp = fopen(saveFile, "rb");
 
@@ -868,7 +924,7 @@ void saveTemporaryData()
 
 	savePtr = NULL;
 
-	snprintf(swapFile, sizeof(swapFile), "%sswap", gameSavePath);
+	SNPRINTF(swapFile, sizeof(swapFile), "%sswap", gameSavePath);
 
 	read = fopen(tempFile, "rb");
 
@@ -1011,7 +1067,7 @@ void saveContinueData()
 
 	savePtr = NULL;
 
-	snprintf(saveFile, sizeof(saveFile), "%scontinuesave", gameSavePath);
+	SNPRINTF(saveFile, sizeof(saveFile), "%scontinuesave", gameSavePath);
 
 	write = fopen(saveFile, "wb");
 
@@ -1185,7 +1241,7 @@ int loadContinueData()
 
 	savePtr = NULL;
 
-	snprintf(saveFile, sizeof(saveFile), "%scontinuesave", gameSavePath);
+	SNPRINTF(saveFile, sizeof(saveFile), "%scontinuesave", gameSavePath);
 
 	fp = fopen(saveFile, "rb");
 
@@ -1286,7 +1342,7 @@ int loadContinueData()
 
 			loadMap(itemName, FALSE);
 
-			snprintf(mapName, sizeof(mapName), "MAP_NAME %s", itemName);
+			SNPRINTF(mapName, sizeof(mapName), "MAP_NAME %s", itemName);
 		}
 
 		else if (strcmpignorecase(line, mapName) == 0)
@@ -1321,7 +1377,7 @@ int hasPersistance(char *mapName)
 
 	savePtr = NULL;
 
-	snprintf(itemName, sizeof(itemName), "MAP_NAME %s", mapName);
+	SNPRINTF(itemName, sizeof(itemName), "MAP_NAME %s", mapName);
 
 	read = fopen(tempFile, "rb");
 
@@ -1430,7 +1486,7 @@ void loadPersitanceData(char *mapName)
 
 	savePtr = NULL;
 
-	snprintf(itemName, sizeof(itemName), "MAP_NAME %s", mapName);
+	SNPRINTF(itemName, sizeof(itemName), "MAP_NAME %s", mapName);
 
 	buffer = decompressFile(tempFile);
 
@@ -1508,7 +1564,7 @@ void loadConfig()
 
 	game.hasConfig = FALSE;
 
-	snprintf(settingsFile, sizeof(settingsFile), "%sconfig", gameSavePath);
+	SNPRINTF(settingsFile, sizeof(settingsFile), "%sconfig", gameSavePath);
 
 	resetControls(FALSE);
 
@@ -1533,7 +1589,7 @@ void loadConfig()
 	{
 		showErrorAndExit("Failed to allocate a whole %ld bytes for config file...", length);
 
-		exit(1);
+		cleanup(1);
 	}
 
 	fseek(fp, 0L, SEEK_SET);
@@ -1573,7 +1629,7 @@ void saveConfig()
 	FILE *fp;
 	char settingsFile[MAX_PATH_LENGTH];
 
-	snprintf(settingsFile, sizeof(settingsFile), "%sconfig", gameSavePath);
+	SNPRINTF(settingsFile, sizeof(settingsFile), "%sconfig", gameSavePath);
 
 	fp = fopen(settingsFile, "wb");
 
@@ -1581,7 +1637,7 @@ void saveConfig()
 	{
 		showErrorAndExit("Could not save settings: %s", strerror(errno));
 
-		exit(1);
+		cleanup(1);
 	}
 
 	writeControlsToFile(fp);
@@ -1637,7 +1693,7 @@ char **getSaveFileIndex()
 	{
 		showErrorAndExit("Failed to allocate a whole %d bytes for save data", (int)sizeof(char *) * MAX_SAVE_SLOTS);
 
-		exit(1);
+		cleanup(1);
 	}
 
 	for (i=0;i<MAX_SAVE_SLOTS;i++)
@@ -1648,7 +1704,7 @@ char **getSaveFileIndex()
 		{
 			showErrorAndExit("Failed to allocate a whole %d bytes for save data", (int)sizeof(char) * MAX_PATH_LENGTH);
 
-			exit(1);
+			cleanup(1);
 		}
 
 		entries[i][0] = '\0';
@@ -1660,7 +1716,7 @@ char **getSaveFileIndex()
 	{
 		/* Check for a save game from version 0.1 */
 
-		snprintf(save0, sizeof(save0), "%ssave0", gameSavePath);
+		SNPRINTF(save0, sizeof(save0), "%ssave0", gameSavePath);
 
 		fp = fopen(save0, "rb");
 
@@ -1696,11 +1752,16 @@ static void showPatchMessage(char *message)
 {
 	int y;
 	SDL_Rect dest;
-	SDL_Surface *title, *completion;
+	Texture *title, *completion;
+	SDL_Surface *text;
 
-	title = generateTextSurface(_("Patching your save game. Please wait..."), game.font, 220, 220, 220, 0, 0, 0);
+	text = generateTextSurface(_("Patching your save game. Please wait..."), game.font, 220, 220, 220, 0, 0, 0);
+	
+	title = convertSurfaceToTexture(text, TRUE);
 
-	completion = generateTextSurface(message, game.font, 220, 220, 220, 0, 0, 0);
+	text = generateTextSurface(message, game.font, 220, 220, 220, 0, 0, 0);
+	
+	completion = convertSurfaceToTexture(text, TRUE);
 
 	if (title == NULL || completion == NULL)
 	{
@@ -1715,8 +1776,8 @@ static void showPatchMessage(char *message)
 	dest.y = y;
 	dest.w = title->w;
 	dest.h = title->h;
-
-	SDL_BlitSurface(title, NULL, game.screen, &dest);
+	
+	SDL_RenderCopy(game.renderer, title->texture, NULL, &dest);
 
 	y += title->h + 15;
 
@@ -1724,16 +1785,16 @@ static void showPatchMessage(char *message)
 	dest.y = y;
 	dest.w = completion->w;
 	dest.h = completion->h;
+	
+	SDL_RenderCopy(game.renderer, completion->texture, NULL, &dest);
 
-	SDL_BlitSurface(completion, NULL, game.screen, &dest);
+	destroyTexture(title);
 
-	SDL_FreeSurface(title);
-
-	SDL_FreeSurface(completion);
+	destroyTexture(completion);
 
 	/* Swap the buffers */
 
-	SDL_Flip(game.screen);
+	SDL_RenderPresent(game.renderer);
 }
 
 void loadObtainedMedals()
@@ -1744,7 +1805,7 @@ void loadObtainedMedals()
 
 	savePtr = NULL;
 
-	snprintf(medalFile, MAX_PATH_LENGTH, "%smedals", gameSavePath);
+	SNPRINTF(medalFile, MAX_PATH_LENGTH, "%smedals", gameSavePath);
 
 	fp = fopen(medalFile, "rb");
 
@@ -1776,7 +1837,7 @@ void saveObtainedMedals()
 	Medal *medal;
 	FILE *fp;
 
-	snprintf(medalFile, MAX_PATH_LENGTH, "%smedals", gameSavePath);
+	SNPRINTF(medalFile, MAX_PATH_LENGTH, "%smedals", gameSavePath);
 
 	fp = fopen(medalFile, "wb");
 
