@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2016 Parallel Realities
+Copyright (C) 2009-2024 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -18,6 +18,10 @@ Foundation, 51 Franklin Street, Suite 500, Boston, MA 02110-1335, USA.
 */
 
 #include "../headers.h"
+
+#if defined(PAK_FILE) && DEV == 0
+#include "../init.h"
+#endif
 #include "pak.h"
 #include "error.h"
 #include "load_save.h"
@@ -31,12 +35,12 @@ static int32_t fileCount;
 
 void initPakFile()
 {
-	#if DEV == 0
+	#if defined(PAK_FILE) && DEV == 0
 		int32_t offset;
 		FILE *fp;
 		int i;
 
-		snprintf(pakFile, sizeof(pakFile), "%s%s", INSTALL_PATH, PAK_FILE);
+		SNPRINTF(pakFile, sizeof(pakFile), "%s%s", INSTALL_PATH, PAK_FILE);
 
 		fp = fopen(pakFile, "rb");
 
@@ -47,7 +51,7 @@ void initPakFile()
 			printf("%s", _("If you compiled the game from source, you need to do a make install"));
 			printf("\n");
 
-			exit(0);
+			cleanup(0);
 		}
 
 		fseek(fp, -(sizeof(int32_t) + sizeof(int32_t)), SEEK_END);
@@ -88,14 +92,16 @@ void initPakFile()
 
 void verifyVersion()
 {
-	char version[5];
+        #if defined(PAK_FILE) && DEV == 0
+            char version[5];
 
-	snprintf(version, sizeof(version), "%0.2f", VERSION);
+            SNPRINTF(version, sizeof(version), "%0.2f", VERSION);
 
-	if (existsInPak(version) == FALSE)
-	{
-		showErrorAndExit("Game and PAK file versions do not match. Please reinstall the game.");
-	}
+			if (existsInPak(version) == FALSE)
+			{
+				showErrorAndExit("Game and PAK file versions do not match. Please reinstall the game.");
+			}
+        #endif
 }
 
 SDL_Surface *loadImageFromPak(char *name)
@@ -110,6 +116,11 @@ SDL_Surface *loadImageFromPak(char *name)
 	rw = SDL_RWFromMem(buffer, size);
 
 	surface = IMG_Load_RW(rw, TRUE);
+	
+	if (surface == NULL)
+	{
+		showErrorAndExit("Failed to load image %s", name);
+	}
 
 	free(buffer);
 
@@ -166,10 +177,13 @@ Mix_Music *loadMusicFromPak(char *name)
 {
 	Mix_Music *music;
 
-	#if DEV == 1
+	#if !defined(PAK_FILE) || DEV == 1
+		char fullName[MAX_PATH_LENGTH];
 		FILE *fp;
 
-		fp = fopen(name, "rb");
+		SNPRINTF(fullName, sizeof(fullName), "%s%s", INSTALL_PATH, name);
+
+		fp = fopen(fullName, "rb");
 
 		if (fp == NULL)
 		{
@@ -178,7 +192,7 @@ Mix_Music *loadMusicFromPak(char *name)
 
 		fclose(fp);
 
-		music = Mix_LoadMUS(name);
+		music = Mix_LoadMUS(fullName);
 
 		return music;
 	#else
@@ -217,12 +231,15 @@ static unsigned char *uncompressFileRW(char *name, unsigned long *size)
 {
 	unsigned char *source, *dest;
 	FILE *fp;
-	#if DEV != 1
+	#if defined(PAK_FILE) && DEV == 0
 		int i, index;
 	#endif
 
-	#if DEV == 1
-		fp = fopen(name, "rb");
+	#if !defined(PAK_FILE) || DEV == 1
+		char fullName[MAX_PATH_LENGTH];
+		SNPRINTF(fullName, sizeof(fullName), "%s%s", INSTALL_PATH, name);
+
+		fp = fopen(fullName, "rb");
 
 		if (fp == NULL)
 		{
@@ -310,13 +327,16 @@ static unsigned char *uncompressFileRW(char *name, unsigned long *size)
 
 static unsigned char *uncompressFile(char *name, int writeToFile)
 {
+	#if !defined(PAK_FILE) || DEV == 1
+		char fullName[MAX_PATH_LENGTH];
+	#else
+		int i;
+		int index = -1;
+	#endif
 	char *filename;
 	unsigned long size;
 	unsigned char *source, *dest;
 	FILE *fp;
-	#if DEV != 1
-		int i, index;
-	#endif
 
 	filename = NULL;
 
@@ -327,8 +347,10 @@ static unsigned char *uncompressFile(char *name, int writeToFile)
 		showErrorAndExit("Failed to allocate a whole %d bytes for filename", MAX_PATH_LENGTH);
 	}
 
-	#if DEV == 1
-		fp = fopen(name, "rb");
+	#if !defined(PAK_FILE) || DEV == 1
+		SNPRINTF(fullName, sizeof(fullName), "%s%s", INSTALL_PATH, name);
+
+		fp = fopen(fullName, "rb");
 
 		if (fp == NULL)
 		{
@@ -355,8 +377,6 @@ static unsigned char *uncompressFile(char *name, int writeToFile)
 
 		source = NULL;
 	#else
-		index = -1;
-
 		for (i=0;i<fileCount;i++)
 		{
 			if (strcmpignorecase(fileData[i].filename, name) == 0)
@@ -412,7 +432,7 @@ static unsigned char *uncompressFile(char *name, int writeToFile)
 		{
 			fclose(fp);
 
-			snprintf(filename, MAX_PATH_LENGTH, "%spakdata", getGameSavePath());
+			SNPRINTF(filename, MAX_PATH_LENGTH, "%spakdata", getGameSavePath());
 
 			printf("Writing to %s\n", filename);
 
@@ -455,14 +475,15 @@ static unsigned char *uncompressFile(char *name, int writeToFile)
 int existsInPak(char *name)
 {
 	int exists;
-	#if DEV == 1
-		FILE *fp;
-	#else
-		int i;
-	#endif
 
-	#if DEV == 1
-		fp = fopen(name, "rb");
+	#if !defined(PAK_FILE) || DEV == 1
+		char fullName[MAX_PATH_LENGTH];
+		FILE *fp;
+
+		SNPRINTF(fullName, sizeof(fullName), "%s%s", INSTALL_PATH, name);
+
+		fp = fopen(fullName, "rb");
+
 
 		if (fp == NULL)
 		{
@@ -476,6 +497,7 @@ int existsInPak(char *name)
 			exists = TRUE;
 		}
 	#else
+		int i;
 		exists = FALSE;
 
 		for (i=0;i<fileCount;i++)
@@ -494,7 +516,7 @@ int existsInPak(char *name)
 
 void freePakFile()
 {
-	#if DEV == 0
+	#if defined(PAK_FILE) && DEV == 0
 		if (fileData != NULL)
 		{
 			free(fileData);
