@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2016 Parallel Realities
+Copyright (C) 2009-2024 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -35,7 +35,9 @@ Foundation, 51 Franklin Street, Suite 500, Boston, MA 02110-1335, USA.
 #include "../graphics/decoration.h"
 #include "../graphics/font.h"
 #include "../graphics/sprites.h"
+#include "../graphics/texture_cache.h"
 #include "../hud.h"
+#include "../init.h"
 #include "../inventory.h"
 #include "../item/item.h"
 #include "../item/key_items.h"
@@ -244,9 +246,9 @@ void freeAllResources()
 
 	freePakFile();
 
-	/* Free the status panel */
+	/* Free the texture cache */
 
-	freeStatusPanel();
+	freeTextureCache();
 
 	if (key != NULL)
 	{
@@ -254,6 +256,8 @@ void freeAllResources()
 		{
 			free(key[i]);
 		}
+		
+		free(key);
 
 		key = NULL;
 	}
@@ -264,6 +268,8 @@ void freeAllResources()
 		{
 			free(value[i]);
 		}
+		
+		free(value);
 
 		value = NULL;
 	}
@@ -339,7 +345,7 @@ char *loadResources(char *buffer)
 			printf("WARNING: Line starts with a space\n");
 
 			#if DEV == 1
-				exit(0);
+				cleanup(0);
 			#endif
 
 			line = strtok_r(NULL, "\n", &savePtr);
@@ -387,7 +393,7 @@ char *loadResources(char *buffer)
 
 		else if (strcmpignorecase(line, "}") == 0)
 		{
-			e = addEntityFromResource(value[type], value[name], startX == -1 ? 0 : atoi(value[startX]), startY == -1 ? 0 : atoi(value[startY]));
+			e = addEntityFromResource(value[type], name == -1 ? "" : value[name], startX == -1 ? 0 : atoi(value[startX]), startY == -1 ? 0 : atoi(value[startY]));
 
 			if (e != NULL)
 			{
@@ -638,7 +644,7 @@ int patchEntities(double versionFile, char *mapName)
 
 	savePtr = NULL;
 
-	snprintf(patchFile, sizeof(patchFile), "data/patch/%0.2f.dat", versionFile);
+	SNPRINTF(patchFile, sizeof(patchFile), "data/patch/%0.2f.dat", versionFile);
 
 	saveMap = TRUE;
 
@@ -766,15 +772,7 @@ int patchEntities(double versionFile, char *mapName)
 			{
 				read = sscanf(line, "%*s %d %d %s %[^\n]s", &x, &y, key, value);
 
-				if (strcmpignorecase(itemName, "PLAYER") == 0)
-				{
-					e = &player;
-				}
-
-				else
-				{
-					e = getEntityByStartXY(x, y);
-				}
+				e = getEntityByStartXY(x, y);
 
 				if (e != NULL)
 				{
@@ -786,15 +784,7 @@ int patchEntities(double versionFile, char *mapName)
 			{
 				read = sscanf(line, "%*s %d %d %s %[^\n]s", &x, &y, key, value);
 
-				if (strcmpignorecase(itemName, "PLAYER") == 0)
-				{
-					e = &player;
-				}
-
-				else
-				{
-					e = getEntityByXY(x, y);
-				}
+				e = getEntityByXY(x, y);
 
 				if (e != NULL)
 				{
