@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2016 Parallel Realities
+Copyright (C) 2009-2024 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -106,7 +106,7 @@ static void touch(Entity *other)
 		{
 			bottomBefore = other->y + other->h - other->dirY - 1;
 
-			if (abs(bottomBefore - self->y) < self->h - 1)
+			if (fabsf(bottomBefore - self->y) < self->h - 1)
 			{
 				if (self->dirY < 0)
 				{
@@ -166,7 +166,7 @@ static Target *getLiftTarget(char *name, int targetID)
 {
 	char targetName[MAX_VALUE_LENGTH];
 
-	snprintf(targetName, sizeof(targetName), "%s_TARGET_%d", name, targetID);
+	SNPRINTF(targetName, sizeof(targetName), "%s_TARGET_%d", name, targetID);
 
 	/* Search for the lift's target */
 
@@ -231,7 +231,7 @@ static void moveToTarget()
 
 	if (self->active == TRUE || self->type == MANUAL_LIFT)
 	{
-		if (abs(self->x - self->targetX) > self->speed)
+		if (fabsf(self->x - self->targetX) > self->speed)
 		{
 			self->dirX = (self->x < self->targetX ? self->speed : -self->speed);
 		}
@@ -241,7 +241,7 @@ static void moveToTarget()
 			self->x = self->targetX;
 		}
 
-		if (abs(self->y - self->targetY) > self->speed)
+		if (fabsf(self->y - self->targetY) > self->speed)
 		{
 			self->dirY = (self->y < self->targetY ? self->speed : -self->speed);
 		}
@@ -353,7 +353,7 @@ static void setToStart()
 
 	else
 	{
-		snprintf(targetName, sizeof(targetName), "%s_TARGET_%d", self->objectiveName, self->health);
+		SNPRINTF(targetName, sizeof(targetName), "%s_TARGET_%d", self->objectiveName, self->health);
 
 		/* Search for the lift's target */
 
