@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2009-2016 Parallel Realities
+Copyright (C) 2009-2024 Parallel Realities
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -91,12 +91,12 @@ static void init()
 	{
 		if (strcmpignorecase(self->name, "common/spawner") == 0 && strstr(token, "/") == NULL)
 		{
-			snprintf(name, sizeof(name), "enemy/%s", token);
+			SNPRINTF(name, sizeof(name), "enemy/%s", token);
 		}
 
 		else
 		{
-			snprintf(name, sizeof(name), "%s", token);
+			SNPRINTF(name, sizeof(name), "%s", token);
 		}
 
 		loadProperties(name, e);
@@ -217,12 +217,12 @@ static void spawn()
 
 						if (strstr(token, "/") == NULL)
 						{
-							snprintf(name, sizeof(name), "enemy/%s", token);
+							SNPRINTF(name, sizeof(name), "enemy/%s", token);
 						}
 
 						else
 						{
-							snprintf(name, sizeof(name), "%s", token);
+							SNPRINTF(name, sizeof(name), "%s", token);
 						}
 
 						e = addEnemy(name, self->x, self->y);
@@ -300,12 +300,12 @@ static void spawn()
 
 				if (strstr(token, "/") == NULL)
 				{
-					snprintf(name, sizeof(name), "enemy/%s", token);
+					SNPRINTF(name, sizeof(name), "enemy/%s", token);
 				}
 
 				else
 				{
-					snprintf(name, sizeof(name), "%s", token);
+					SNPRINTF(name, sizeof(name), "%s", token);
 				}
 
 				e = addEnemy(name, self->x, self->y);
